* Prepare cohort data for FIGURES 4, 11 and 18

local folder = "..\empirical\figure4"
cd `folder'

clear

u cohort_scarscex_replication

local age_ent = 25
local age_lm = 64

* COHORTS
* -------gibson 335

* Cohorts In 2007: young 25-34, medium: 35-49, old: 50-60
gen age_07 = 2007 - y_birth
gen coh_y = 0
gen coh_m = 0
gen coh_o = 0
replace coh_y = 1 if (y_birth<=(2007-`age_ent') & y_birth>(2007-(`age_ent'+10)) )
replace coh_m = 1 if (y_birth<=(2007-(`age_ent'+10)) & y_birth>(2007-(`age_ent'+20)) )
replace coh_o = 1 if (y_birth<=(2007-(`age_ent'+20)) & y_birth>(2007-(`age_ent'+30)) )

gen coh_block_age = .
replace coh_block_age = 1 if coh_y==1
replace coh_block_age = 2 if coh_m==1
replace coh_block_age = 3 if coh_o==1
label define coh_block_agel 1 "25-34" 2 "35-44" 3 "45-54"
label values coh_block_age coh_block_agel
label variable coh_block_age "Cohort"

* EDUCATION
* -------
gen h_educ1_cl = h_educ1
gen h_educ2_cl = h_educ2
gen h_educ3_cl = h_educ3
replace  h_educ1_cl =  0 if (h_educ2==1 | h_educ3==1 | h_educ4==1)
replace  h_educ2_cl =  0 if (h_educ3==1 | h_educ4==1)
replace  h_educ3_cl =  0 if (h_educ4==1)

gen coh_block_edu = .
forval t=2007/2012 {	
	qui replace coh_block_edu = 1 if  (year==`t' & h_educ1_cl==1 & coh_block_age!=.)
    qui replace coh_block_edu = 2 if  (year==`t' & h_educ2_cl==1 & coh_block_age!=.)
    qui replace coh_block_edu = 3 if  (year==`t' & h_educ3_cl==1 & coh_block_age!=.)
	qui replace coh_block_edu = 4 if  (year==`t' & h_educ4==1 & coh_block_age!=.)
}

label define coh_block_edul 1 "drop out" 2 "high school" 3 "some college" 4 "college"
label values coh_block_edu coh_block_edul
label variable coh_block_edu "Head's education"

gen age_sq = age^2
gen age_cu = age^3
gen age_qu = age^4

* LIFE-CYCLE PROFILES
qui regress CGROWTH age age_sq age_cu age_qu coh_dum3-coh_dum8 year if (year<=2007 & age>=`age_ent' & age<=`age_lm')
qui predict PR_CGROWTH, xb
qui regress CARINV age age_sq age_cu age_qu coh_dum3-coh_dum8 year  if (year<=2007 & age>=`age_ent' & age<=`age_lm')
qui predict PR_CARINV, xb
qui regress P_BUY age age_sq age_cu age_qu coh_dum3-coh_dum8 year if (year<=2007 & age>=`age_ent' & age<=`age_lm')
qui predict PR_P_BUY, xb
qui regress CARSPEND age age_sq age_cu age_qu coh_dum3-coh_dum8  year  if (year<=2007 & age>=`age_ent' & age<=`age_lm')
qui predict PR_CARSPEND, xb
replace PR_CARSPEND = . if CARSPEND==.
qui regress P_SAVE age age_sq age_cu age_qu coh_dum3-coh_dum8 year if (year<=2007 & age>=`age_ent' & age<=`age_lm')
qui predict PR_P_SAVE, xb
qui regress CLOAN age age_sq age_cu age_qu coh_dum3-coh_dum8 year if (year>=1993 & year<=2007 & age>=`age_ent' & age<=`age_lm')
qui predict PR_CLOAN, xb

gen year_pr = 1
replace year_pr = 2 if year>=2006 & year<=2007

gen year_gr = 1
replace year_gr = 2 if year>=2008 & year<=2010

* CONSUMPTION GROWTH
qui bys coh_block_age year_gr: egen cgrowth_gr = mean(CGROWTH)
qui bys coh_block_age: egen cgrowth_cy0_temp = mean(CGROWTH) if year_pr==2
qui bys coh_block_age: egen cgrowth_cy0 = mean(cgrowth_cy0_temp)
gen d_cgrowth_gr = cgrowth_gr - cgrowth_cy0

qui bys coh_block_age year_gr: egen pr_cgrowth_gr = mean(PR_CGROWTH)
qui bys coh_block_age: egen pr_cgrowth_cy0_temp = mean(PR_CGROWTH) if year_pr==2
qui bys coh_block_age: egen pr_cgrowth_cy0 = mean(pr_cgrowth_cy0_temp)
gen pr_d_cgrowth_gr = pr_cgrowth_gr - pr_cgrowth_cy0
gen d_cgrowth_gr_gap = d_cgrowth_gr - pr_d_cgrowth_gr

* CAR INVESTMENT
qui bys coh_block_age year_gr: egen carinv_gr = mean(CARINV)
qui bys coh_block_age: egen carinv_cy0_temp = mean(CARINV) if year_pr==2
qui bys coh_block_age: egen carinv_cy0 = mean(carinv_cy0_temp)
gen d_carinv_gr = carinv_gr/carinv_cy0 - 1

qui bys coh_block_age year_gr: egen pr_carinv_gr = mean(PR_CARINV)
qui bys coh_block_age: egen pr_carinv_cy0_temp = mean(PR_CARINV) if year_pr==2
qui bys coh_block_age: egen pr_carinv_cy0 = mean(pr_carinv_cy0_temp)
gen pr_d_carinv_gr = pr_carinv_gr/pr_carinv_cy0 - 1
gen d_carinv_gr_gap = d_carinv_gr - pr_d_carinv_gr

* PROBABILITY OF PURCHASE
qui bys coh_block_age year_gr: egen p_buy_gr = mean(P_BUY)
qui bys coh_block_age: egen p_buy_cy0_temp = mean(P_BUY) if year_pr==2
qui bys coh_block_age: egen p_buy_cy0 = mean(p_buy_cy0_temp)
gen d_p_buy_gr = p_buy_gr - p_buy_cy0

qui bys coh_block_age year_gr: egen pr_p_buy_gr = mean(PR_P_BUY)
qui bys coh_block_age: egen pr_p_buy_cy0_temp = mean(PR_P_BUY) if year_pr==2
qui bys coh_block_age: egen pr_p_buy_cy0 = mean(pr_p_buy_cy0_temp)
gen pr_d_p_buy_gr = pr_p_buy_gr - pr_p_buy_cy0
gen d_p_buy_gr_gap = d_p_buy_gr - pr_d_p_buy_gr

* CAR SPEND CONDITIONAL ON ADJUST
qui bys coh_block_age year_gr: egen carspend_gr = mean(CARSPEND)
qui bys coh_block_age: egen carspend_cy0_temp = mean(CARSPEND) if year_pr==2
qui bys coh_block_age: egen carspend_cy0 = mean(carspend_cy0_temp)
gen d_carspend_gr = carspend_gr/carspend_cy0 - 1

qui bys coh_block_age year_gr: egen pr_carspend_gr = mean(PR_CARSPEND)
qui bys coh_block_age: egen pr_carspend_cy0_temp = mean(PR_CARSPEND) if year_pr==2
qui bys coh_block_age: egen pr_carspend_cy0 = mean(pr_carspend_cy0_temp)
gen pr_d_carspend_gr = pr_carspend_gr/pr_carspend_cy0 - 1
gen d_carspend_gr_gap = d_carspend_gr - pr_d_carspend_gr

* SHARE SAVING
qui bys coh_block_age year_gr: egen p_save_gr = mean(P_SAVE)
qui bys coh_block_age: egen p_save_cy0_temp = mean(P_SAVE) if year_pr==2
qui bys coh_block_age: egen p_save_cy0 = mean(p_save_cy0_temp)
gen d_p_save_gr = p_save_gr - p_save_cy0

qui bys coh_block_age year_gr: egen pr_p_save_gr = mean(PR_P_SAVE)
qui bys coh_block_age: egen pr_p_save_cy0_temp = mean(PR_P_SAVE) if year_pr==2
qui bys coh_block_age: egen pr_p_save_cy0 = mean(pr_p_save_cy0_temp)
gen pr_d_p_save_gr = pr_p_save_gr - pr_p_save_cy0
gen d_p_save_gr_gap = d_p_save_gr - pr_d_p_save_gr

* CAR LOANS
qui bys coh_block_age year_gr: egen cloan_gr = mean(CLOAN)
qui bys coh_block_age: egen cloan_cy0_temp = mean(CLOAN) if year_pr==2
qui bys coh_block_age: egen cloan_cy0 = mean(cloan_cy0_temp)
gen d_cloan_gr = cloan_gr/cloan_cy0 - 1

qui bys coh_block_age year_gr: egen pr_cloan_gr = mean(PR_CLOAN)
qui bys coh_block_age: egen pr_cloan_cy0_temp = mean(PR_CLOAN) if year_pr==2
qui bys coh_block_age: egen pr_cloan_cy0 = mean(pr_cloan_cy0_temp)
gen pr_d_cloan_gr = pr_cloan_gr/pr_cloan_cy0 - 1
gen d_cloan_gr_gap = d_cloan_gr - pr_d_cloan_gr

* VARIABLES BY EDUCATION GROUPS

* CAR INVESTMENT
qui bys coh_block_edu year_gr: egen carinv_edu = mean(CARINV)
qui bys coh_block_edu: egen carinv_edu_cy0_temp = mean(CARINV) if year_pr==2
qui bys coh_block_edu: egen carinv_edu_cy0 = mean(carinv_edu_cy0_temp)
gen d_carinv_edu = carinv_edu/carinv_edu_cy0 - 1

qui bys coh_block_edu year_gr: egen pr_carinv_edu = mean(PR_CARINV)
qui bys coh_block_edu: egen pr_carinv_edu_cy0_temp = mean(PR_CARINV) if year_pr==2
qui bys coh_block_edu: egen pr_carinv_edu_cy0 = mean(pr_carinv_edu_cy0_temp)
gen pr_d_carinv_edu = pr_carinv_edu/pr_carinv_edu_cy0 - 1
gen d_carinv_edu_gap = d_carinv_edu - pr_d_carinv_edu

* PROBABILITY OF PURCHASE
qui bys coh_block_edu year_gr: egen p_buy_edu = mean(P_BUY)
qui bys coh_block_edu: egen p_buy_edu_cy0_temp = mean(P_BUY) if year_pr==2
qui bys coh_block_edu: egen p_buy_edu_cy0 = mean(p_buy_edu_cy0_temp)
gen d_p_buy_edu = p_buy_edu - p_buy_edu_cy0

qui bys coh_block_edu year_gr: egen pr_p_buy_edu = mean(PR_P_BUY)
qui bys coh_block_edu: egen pr_p_buy_edu_cy0_temp = mean(PR_P_BUY) if year_pr==2
qui bys coh_block_edu: egen pr_p_buy_edu_cy0 = mean(pr_p_buy_edu_cy0_temp)
gen pr_d_p_buy_edu = pr_p_buy_edu - pr_p_buy_edu_cy0
gen d_p_buy_edu_gap = d_p_buy_edu - pr_d_p_buy_edu

* CAR SPEND CONDITIONAL ON ADJUST
qui bys coh_block_edu year_gr: egen carspend_edu = mean(CARSPEND)
qui bys coh_block_edu: egen carspend_edu_cy0_temp = mean(CARSPEND) if year_pr==2
qui bys coh_block_edu: egen carspend_edu_cy0 = mean(carspend_edu_cy0_temp)
gen d_carspend_edu = carspend_edu/carspend_edu_cy0 - 1

qui bys coh_block_edu year_gr: egen pr_carspend_edu = mean(PR_CARSPEND)
qui bys coh_block_edu: egen pr_carspend_edu_cy0_temp = mean(PR_CARSPEND) if year_pr==2
qui bys coh_block_edu: egen pr_carspend_edu_cy0 = mean(pr_carspend_edu_cy0_temp)
gen pr_d_carspend_edu = pr_carspend_edu/pr_carspend_edu_cy0 - 1
gen d_carspend_edu_gap = d_carspend_edu - pr_d_carspend_edu


preserve

keep if year_gr==2
qui bys coh_block_age: gen n1=_n
keep if n1==1
keep if coh_block_age!=.
sort coh_block_age

outsheet d_cgrowth_gr_gap d_carinv_gr_gap d_p_buy_gr_gap  ///
d_carspend_gr_gap d_p_save_gr_gap d_cloan_gr_gap ///
  using "./cohort_cex_data.csv" if n1==1, comma replace
  
restore

preserve

keep if year_gr==2
qui bys coh_block_edu: gen n1=_n
keep if n1==1
keep if coh_block_edu!=.
sort coh_block_edu

outsheet d_carinv_edu_gap d_p_buy_edu_gap d_carspend_edu_gap ///
  using "./cohort_cex_data_education.csv" if n1==1, comma replace
  
restore