  SUBROUTINE sub_shocks_mnth_a(init_x_shock_m, init_d_shock_m, init_p_shock_m, init_u_shock_m, &
	init_d_nadj_shock_m,init_delta_shock_m,init_clunk_shock_m)

  ! Generates sequence of idiosyncratic and aggregate shocks

  USE share
  USE OMP_LIB
  USE par_zig_mod

  IMPLICIT NONE

  REAL(8), DIMENSION(agents,rep), INTENT(OUT) :: &
	 init_x_shock_m, init_d_shock_m, init_p_shock_m, init_u_shock_m
  INTEGER, DIMENSION(agents,rep), INTENT(OUT) :: init_d_nadj_shock_m, init_delta_shock_m
  INTEGER, DIMENSION(clunk_dur_m,agents,rep), INTENT(OUT) :: init_clunk_shock_m

  REAL(8) :: init_y_shock_temp
  REAL(8), DIMENSION(agents) :: rand_shock_vec
  INTEGER, DIMENSION(agents) :: rand_int_vec
  INTEGER :: time, month, time_m, i, j, k, l, m, o

  INTEGER  :: reset, npar, numthreads
  INTEGER, DIMENSION(agents)  :: kpar
  INTEGER, DIMENSION(:), ALLOCATABLE :: seed
  INTEGER :: grainsize = 32

  !$OMP PARALLEL
  !$OMP DO
  DO i=1, agents
  init_p_shock_m(i,:) = 0.d0
  init_u_shock_m(i,:) = 0.d0
  init_x_shock_m(i,:) = 0.d0
  init_d_shock_m(i,:) = 0.d0
  init_d_nadj_shock_m(i,:) = 0
  init_delta_shock_m(i,:) = 0
  init_clunk_shock_m(:,i,:) = 0
  END DO
  !$OMP END DO
  !$OMP END PARALLEL


  ! 0. Set up parallel probability generator
  !----------
  !$OMP PARALLEL
  numthreads = OMP_get_num_threads()
  !$OMP END PARALLEL
  npar=numthreads+1

  ALLOCATE( seed(npar) )
  DO i = 1,npar
        seed(i) = 12345678 * i
  END DO

  reset=0
  CALL par_zigset(npar, seed, grainsize,reset)

  !$OMP PARALLEL
  !$OMP DO
  DO i=1, agents
     kpar(i) = omp_get_thread_num()+1
     DO j = 1, rep
	  rand_shock_vec(i)=par_rnor(kpar(i))
	  init_p_shock_m(i,j) = ilp_age1_m + ilp_stdage1_m * rand_shock_vec(i)
	  rand_shock_vec(i)=par_rnor(kpar(i))
	  init_u_shock_m(i,j) = mu_ma_age1_m + cov_pma_age1_m*init_p_shock_m(i,j) + &
		 sigma_ma_age1_m * rand_shock_vec(i)
          init_p_shock_m(i,j) = EXP( init_p_shock_m(i,j) )
          init_u_shock_m(i,j) = EXP( init_u_shock_m(i,j) )

	  rand_shock_vec(i)=par_rnor(kpar(i))
	  init_d_shock_m(i,j) = EXP( ild_age1 + ild_stdage1 * rand_shock_vec(i) )
	  rand_shock_vec(i)=par_uni(kpar(i))
          IF ( rand_shock_vec(i)> 1.d0 - (1.d0-p_adj_0*p_adj_0_tune)**DBLE(1.d0/mnth) ) THEN
	  init_d_nadj_shock_m(i,j) = 1
          END IF
          rand_shock_vec(i)=par_rnor(kpar(i))
	  init_x_shock_m(i,j) = MAX( ik_age1 + ik_stdage1 * rand_shock_vec(i), -eta*init_d_shock_m(i,j) )
          IF (init_x_shock_m(i,j) >0.d0) THEN
          init_x_shock_m(i,j) = init_x_shock_m(i,j)*r_m
          ELSE
          init_x_shock_m(i,j) = init_x_shock_m(i,j)*(r_m + rk_m)
          END IF
            DO time=1,clunk_dur_m
              rand_shock_vec(i)=par_uni(kpar(i))
              IF (rand_shock_vec(i) <= clunk_dis_m) THEN
              init_clunk_shock_m(time,i,j) = 1
              ELSE
              init_clunk_shock_m(time,i,j) = 2
              END IF
            END DO

          rand_shock_vec(i)=par_uni(kpar(i))
          IF (rand_shock_vec(i) <= Probdpcum_m(1,1) ) THEN
          init_delta_shock_m(i,j) = 1
          ELSE
          init_delta_shock_m(i,j) = 2
          END IF
     END DO
  END DO
  !$OMP END DO
  !$OMP END PARALLEL

  !$OMP PARALLEL
  !$OMP DO
  DO i=1,agents
  kpar(i) = omp_get_thread_num()+1
  rand_shock_vec(i)=par_rnor(kpar(i))
  END DO
  !$OMP END DO
  !$OMP END PARALLEL


  END SUBROUTINE sub_shocks_mnth_a
