clear all
close all

%data = load('/PATH/full_model/out/Shockmat.txt');
data = load('out/Shockmat.txt');
model_spec = importdata('out/model_spec');

disp('Read data')

age1 = 25;
twork = 40;
trest = 20;
age_cutoff = 35+6;
ng = twork+trest;

reg_min_a = 1;
reg_max_a = age_cutoff;

% Shock simulate parameters
rep_out = 150;
rep_out_use = 150;

agent_age= 2000;
agents = agent_age * ng;
agents_out_sc = 2;
agents_out = floor(agents/agents_out_sc);
year0 = 1980;     % first year of simulation
yearN = 2018;
shockseriesmat_n = yearN-1980+1;
data_yearN = 2012;
year_p0 = 2005;   % Year of first prediction
year_r0 = 2007;   % Year of last regression
year1 = yearN - shockseriesmat_n+1;
data_time1 = 1982;
time = year1:yearN;
VAR = 6;

coh_size = 10;
coh_start = 3; % Start each cohort in year 19x{ coh_start }. E.g. 0 = 19x0

cgr = data(1,:);
iex = data(2,:);
val = data(3,:);
adj = (val~=-123);
d = data(4,:);
wealth = data(5,:);
savr = data(6,:);
loan = data(7,:);
age = data(8,:);

clear data

cgr = reshape(cgr,shockseriesmat_n,agents_out,rep_out);
iex = reshape(iex,shockseriesmat_n,agents_out,rep_out);
val = reshape(val,shockseriesmat_n,agents_out,rep_out);
adj = reshape(adj,shockseriesmat_n,agents_out,rep_out);
d = reshape(d,shockseriesmat_n,agents_out,rep_out);
wealth = reshape(wealth,shockseriesmat_n,agents_out,rep_out);
savr = reshape(savr,shockseriesmat_n,agents_out,rep_out);
loan = reshape(loan,shockseriesmat_n,agents_out,rep_out);
age = reshape(age,shockseriesmat_n,agents_out,rep_out);

xx = 1:rep_out_use;
cgr = cgr(:,:,xx);
iex = iex(:,:,xx);
val = val(:,:,xx);
adj = adj(:,:,xx);
d = d(:,:,xx);
wealth = wealth(:,:,xx);
savr = savr(:,:,xx);
loan = loan(:,:,xx);
age = age(:,:,xx);

year = repmat(time',1,agents_out,rep_out_use);
rep_mat = reshape(kron((1:rep_out_use),ones(shockseriesmat_n*agents_out,1)),[shockseriesmat_n,agents_out,rep_out_use]);

p_sav = savr<1;


% Align cohort groups with data
if coh_size ==10
max_cohort_yr0 = mod( ((year0-1)-age1), 10 ) - coh_start + 1;
end
cohort_adjust = coh_size-( sum( ceil(((ng:-1:1))/coh_size)==ceil(ng/coh_size) ) - max_cohort_yr0 );
init_max_coh = ceil((ng+cohort_adjust)/coh_size);
num_max_coh = sum( ceil(((ng:-1:1)+cohort_adjust)/coh_size)==init_max_coh );
if num_max_coh~=max_cohort_yr0
    disp('ERROR in cohorts alignment')
end

% Construct cohort variable
coh = zeros(shockseriesmat_n,agents_out,rep_out_use);
age0 = age(1,:,:)-1 ; % age in 1970
age0(age0==0) = ng;
age0(age0==-2) = -1;

age(age>age_cutoff) = -1; % Drop age for those above cut off
coh_temp = abs(age0-ng-1); % age in 1970, reversed: age1=55, age11=1, dead=57
coh_temp(coh_temp>ng)=-cohort_adjust; % if dead set to cohort adjust (will== be given cohort 0)
coh_temp = ceil( ( coh_temp+cohort_adjust )/coh_size); % Find relevant cohort age1=init_max_cohort

coh(1,:,:) = coh_temp;

% Update first row (counter=size of youngest cohort in 1970, max coh=label (defined end of previous period))
counter = num_max_coh;
max_coh=init_max_coh;
if counter<coh_size-1 % Space to add one more set all age1 = max cohort
counter = counter+1;
coh(1,age(1,:,:)==1)=max_coh;
elseif counter==coh_size-1 % Space to add one more, but then update max
coh(1,age(1,:,:)==1)=max_coh;
max_coh = max_coh+1;
counter = 0;
elseif counter==coh_size % Age 25 are new cohort
max_coh = max_coh+1;
coh(1,age(1,:,:)==1)=max_coh;
counter = 1;
end

% Form future cohorts
for i=2:shockseriesmat_n
counter = counter+1 ;
coh(i,:,:) = coh(i-1,:,:);
coh(i,age(i,:,:)==1)=max_coh;
if counter==coh_size && i<shockseriesmat_n
    max_coh = max_coh+1;
    counter = 0;
end
end
disp('Created series')

% profile
t_r0 = dsearchn(time',year_r0);
t_p0 = dsearchn(time',year_p0);
t_st = dsearchn(time',data_time1);
y_data_reg = [reshape(coh(t_st:t_r0,:,:),[],1),...  % Select pre-recession data
    reshape(age(t_st:t_r0,:,:),[],1), ...
    reshape(iex(t_st:t_r0,:,:),[],1), ...
    reshape(val(t_st:t_r0,:,:),[],1), ...
    reshape(adj(t_st:t_r0,:,:),[],1), ...
    reshape(p_sav(t_st:t_r0,:,:),[],1), ...
    reshape(cgr(t_st:t_r0,:,:),[],1), ...
    reshape(loan(t_st:t_r0,:,:),[],1), ...
    reshape(rep_mat(t_st:t_r0,:,:),[],1), ...
    reshape(year(t_st:t_r0,:,:),[],1) ] ; % Year trend

y_data_pred = [reshape(coh(t_p0:end,:,:),[],1),...  % Select pre-recession data
    reshape(age(t_p0:end,:,:),[],1), ...
    reshape(rep_mat(t_p0:end,:,:),[],1), ...
    reshape(year(t_p0:end,:,:),[],1)] ;  % Year trend

y_out_pred = zeros(length(y_data_pred),VAR);

coh_eye = eye( max( y_data_reg(:,1) ) );
coh_dum = coh_eye(max(y_data_reg(:,1),1) ,:);  % note agents that start dead coh=0, set coh==1
min_coh_reg = min(y_data_reg(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a,1));
max_coh_reg = max(y_data_reg(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a,1));
coh_dum = coh_dum(:,min_coh_reg+1:end);

coh_dum_pred = coh_eye(min(max(y_data_pred(:,1),1),max_coh_reg),:);
coh_dum_pred = coh_dum_pred(:,min_coh_reg+1:end);

BETA = zeros(5+size(coh_dum,2)+1,VAR);  % Year trend

% Year trend
age_bloc = [ones(length(y_data_reg),1), y_data_reg(:,2),y_data_reg(:,2).^2,...
    y_data_reg(:,2).^3,y_data_reg(:,2).^4,...
    coh_dum,y_data_reg(:,end)];
age_bloc_pred = [ones(length(y_data_pred),1), y_data_pred(:,2),y_data_pred(:,2).^2,...
    y_data_pred(:,2).^3,y_data_pred(:,2).^4,...
    coh_dum_pred,y_data_pred(:,end)];

clear coh_dum coh_dum_pred

% regression for each variable
for i=1:VAR
if i==2 % value | adjust
    ytemp=y_data_reg(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a & y_data_reg(:,5)==1,2+i) ;
    xtemp=age_bloc(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a & y_data_reg(:,5)==1,:);
elseif i==5 % % Consumption growth
    ytemp=y_data_reg(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a & y_data_reg(:,7)~=-123,2+i) ;
    xtemp=age_bloc(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a & y_data_reg(:,7)~=-123,:);
elseif i==6 % loan >0
    ytemp=y_data_reg(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a & y_data_reg(:,8)>0,2+i) ;
    xtemp=age_bloc(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a & y_data_reg(:,8)>0,:);
else
    ytemp=y_data_reg(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a,2+i) ;
    xtemp=age_bloc(y_data_reg(:,2)>=reg_min_a & y_data_reg(:,2)<=reg_max_a,:);
end

if rank(xtemp)==size(xtemp,2)
BETA(:,i) = regress(ytemp,xtemp);
else
BETA(1:end-1,i) = regress(ytemp,xtemp(:,1:end-1));
end

y_out_pred(:,i) = age_bloc_pred*BETA(:,i);

clear ytemp xtemp
end

iex_pred = reshape(y_out_pred(:,1),yearN-year_p0+1,agents_out,rep_out_use);
val_pred = reshape(y_out_pred(:,2),yearN-year_p0+1,agents_out,rep_out_use);
adj_pred = reshape(y_out_pred(:,3),yearN-year_p0+1,agents_out,rep_out_use);
p_sav_pred = reshape(y_out_pred(:,4),yearN-year_p0+1,agents_out,rep_out_use);
cgr_pred = reshape(y_out_pred(:,5),yearN-year_p0+1,agents_out,rep_out_use);
loan_pred = reshape(y_out_pred(:,6),yearN-year_p0+1,agents_out,rep_out_use);
clear y_data_reg y_out_pred age_bloc age_bloc_pred
disp('Run expenditure regressions')

% Construct three mean groups: (young, medium, old)
coh_gr = 3;
coh_yr0 = 2007;
coh_block07 = [1,10;11,20;21,30];

year_gr = [2008,2010];
year_gr2 = [2009,2011];
year_gr3 = [2008,2010];
coh_t = zeros(size(age));

% From prediction yr1-end plus GR and PR mean
iex_mean = nan(yearN-year_p0+1+1,coh_gr);
val_mean=iex_mean;
adj_mean=iex_mean;
p_sav_mean=iex_mean;
cgr_mean =iex_mean;
loan_mean =iex_mean;

age_mean=iex_mean;
age_min=iex_mean;
age_max=iex_mean;
coh_mean =iex_mean;

iex_pred_mean = nan(yearN-year_p0+1+1,coh_gr);
val_pred_mean=iex_mean;
adj_pred_mean=iex_mean;
p_sav_pred_mean=iex_mean;
cgr_pred_mean=iex_mean;
loan_pred_mean =iex_mean;

% Construct means logs from model data for year_p0-end
for i=1:yearN-year_p0+1
    t = i+t_p0-1;
    for j=1:coh_gr

        age_lb = max(coh_block07(j,1)+i-(coh_yr0-year_p0)-1,1);  % pre-recession not full group size for coh1
        age_ub = coh_block07(j,2)+i-(coh_yr0-year_p0)-1;
        coh_t(t,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub) = j;
        iex_mean(i,j) = mean(iex(t,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        val_mean(i,j) = mean(val(t,adj(t,:,:)==1 & age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        adj_mean(i,j) = mean(adj(t,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        p_sav_mean(i,j) = mean(p_sav(t,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        cgr_mean(i,j) = mean(cgr(t,cgr(t,:,:)~=-123 & age(t,:,:)>=age_lb & age(t,:,:)<=age_ub ));
        loan_mean(i,j) = mean(loan(t,loan(t,:,:)>0 & age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));

        age_mean(i,j) = mean(age(t,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub ));
        age_min(i,j) = min(age(t,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub ));
        age_max(i,j) = max(age(t,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub ));
        coh_mean(i,j) = mean(coh(t,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub ));

        % Predicted
        iex_pred_mean(i,j) = mean(iex_pred(i,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        val_pred_mean(i,j) = mean(val_pred(i,adj(t,:,:)==1 & age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        adj_pred_mean(i,j) = mean(adj_pred(i,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        p_sav_pred_mean(i,j) = mean(p_sav_pred(i,age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        cgr_pred_mean(i,j) = mean(cgr_pred(i,cgr(t,:,:)~=-123 & age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));
        loan_pred_mean(i,j) = mean(loan_pred(i,loan(t,:,:)>0 & age(t,:,:)>=age_lb & age(t,:,:)<=age_ub));

    end
end
disp('Found year deviations')

% Great Recession
t = dsearchn(time',year_gr(1)):dsearchn(time',year_gr(2));
i = t-t_p0+1;
D = zeros(size(coh_t));
D(t,:,:) = coh_t(t,:,:);
D_adj = D;
D_loan = D;
D_adj(adj==0)=0;
D_loan(loan<=0)=0;

E = zeros(size(iex_pred));
E(i,:,:) = coh_t(t,:,:);
E_adj = E;
E_loan = E;
E_adj(adj(t_p0:end,:,:)==0)=0;
E_loan(loan(t_p0:end,:,:)<=0)=0;

t2 = dsearchn(time',year_gr2(1)):dsearchn(time',year_gr2(2));
i2 = t2-t_p0+1;
D2 = zeros(size(coh_t));
D2(t2,:,:) = coh_t(t2,:,:);
E2 = zeros(size(iex_pred));
E2(i2,:,:) = coh_t(t2,:,:);

t3 = dsearchn(time',year_gr3(1)):dsearchn(time',year_gr3(2));
i3 = t3-t_p0+1;
D3_cgr = zeros(size(coh_t));
D3_cgr(t3,:,:) = coh_t(t3,:,:);
D3_cgr(cgr==-123)=0;
E3_cgr = zeros(size(iex_pred));
E3_cgr(i3,:,:) = coh_t(t3,:,:);
E3_cgr(cgr(t_p0:end,:,:)==-123)=0;

for j=1:coh_gr
    iex_mean(end,j) = mean(iex(D==j));
    val_mean(end,j) = mean(val(D_adj==j));
    adj_mean(end,j) = mean(adj(D==j));
    p_sav_mean(end,j) = mean(p_sav(D2==j));
    cgr_mean(end,j) = mean(cgr(D3_cgr==j));
    loan_mean(end,j) = mean(loan(D_loan==j));

    age_mean(end,j) = mean(age(D==j));
    age_min(end,j) = min(age(D==j));
    age_max(end,j) = max(age(D==j));
    coh_mean(end,j) = mean(coh(D==j));

    % Predicted
    iex_pred_mean(end,j) = mean(iex_pred(E==j));
    val_pred_mean(end,j) = mean(val_pred(E_adj==j));
    adj_pred_mean(end,j) = mean(adj_pred(E==j));
    p_sav_pred_mean(end,j) = mean(p_sav_pred(E2==j));
    cgr_pred_mean(end,j) = mean(cgr_pred(E3_cgr==j));
    loan_pred_mean(end,j) = mean(loan_pred(E_loan==j));
end
disp('Found Great Recession means')

yrs_print=1;
yprint = length(iex_mean);

iex_table = zeros(coh_gr,3);  % Baseline 2007
val_table = iex_table;
adj_table = iex_table;
p_sav_table = iex_table;
cgr_table = iex_table;
loan_table = iex_table;

bs1 = 3; % 2007
bs2 = 4; % 2008

for j=1:coh_gr

    iex_table(j,1) = iex_mean(end,j)/iex_mean(bs1,j)-1;
    iex_table(j,2) = iex_pred_mean(end,j)/iex_pred_mean(bs1,j)-1;
    iex_table(j,3) = iex_table(j,1)-iex_table(j,2);

    val_table(j,1) = val_mean(end,j)/val_mean(bs1,j)-1;
    val_table(j,2) = val_pred_mean(end,j)/val_pred_mean(bs1,j)-1;
    val_table(j,3) = val_table(j,1)-val_table(j,2);

    adj_table(j,1) = adj_mean(end,j)-adj_mean(bs1,j);
    adj_table(j,2) = adj_pred_mean(end,j)-adj_pred_mean(bs1,j);
    adj_table(j,3) = adj_table(j,1)-adj_table(j,2);

    p_sav_table(j,1) = p_sav_mean(end,j) - p_sav_mean(bs2,j);
    p_sav_table(j,2) = p_sav_pred_mean(end,j) - p_sav_pred_mean(bs2,j);
    p_sav_table(j,3) = p_sav_table(j,1)-p_sav_table(j,2);

    cgr_table(j,1) = cgr_mean(end,j)-cgr_mean(bs1,j);
    cgr_table(j,2) = cgr_pred_mean(end,j)-cgr_pred_mean(bs1,j);
    cgr_table(j,3) = cgr_table(j,1)-cgr_table(j,2);

    loan_table(j,1) = loan_mean(end,j)/loan_mean(bs1,j)-1;
    loan_table(j,2) = loan_pred_mean(end,j)/loan_pred_mean(bs1,j)-1;
    loan_table(j,3) = loan_table(j,1)-loan_table(j,2);
end

cohort_out = [cgr_table(:,3)';iex_table(:,3)';adj_table(:,3)';val_table(:,3)';p_sav_table(:,3)';loan_table(:,3)'];
if  strtrim(model_spec)=="growth"
mdl_base = cohort_out;
end

data_cex = csvread('cohort_cex_data.csv',1,0)';
data_w = abs(data_cex)./sum(abs(data_cex),2);

ABSDEV = 10*sum( abs(cohort_out-data_cex).*data_w , 2 )';
m_ABSDEV = mean(ABSDEV);
ABSDEV_out = [ABSDEV,m_ABSDEV];

disp('Table 6, Panel b')
disp('Cohort model fit:')
print_absdev = sprintf('  %1.3f  ',ABSDEV_out);
disp( print_absdev );

if  strtrim(model_spec)=="growth"
disp('Begin Wealth/Education estimates')
% WEALTH / EDUCATION
coh_age_gr = 3;       % Number of age groups
coh_w_gr = 4;           % Bins for income/wealth

% Where conditioning on adjustment
adj_n = 0;
adj_dummy = zeros(size(adj));

% Wealth groups
coh_block07 = [1,10;11,20;21,30;31,40];
coh_slc_w = zeros(size(age));
coh_slc_w = coh_slc_w(1,:,:);
wealth_yr0 = 2007;
wealth_pc = [10.55,37.36,66.35];   % Education shares from CEX: drop out, high school, some college, completed college

% Wealth distribution in year0
tw0 = t_p0 + (wealth_yr0-year_p0);
wealth_cnt = wealth + d; % Wealth + car stock (EDU proxy)

for j=1:coh_age_gr
    age_lb = max(coh_block07(j,1)-(coh_yr0-wealth_yr0), 1);  % pre-recession not full group size for coh1
    age_ub = coh_block07(j,2)-(coh_yr0-wealth_yr0);

    for k=0:adj_n
    wealth_pc1 = prctile(wealth_cnt(tw0,age(tw0,:,:)>=age_lb & age(tw0,:,:)<=age_ub & adj_dummy(tw0,:,:)==k),wealth_pc(1));
    wealth_pc2 = prctile(wealth_cnt(tw0,age(tw0,:,:)>=age_lb & age(tw0,:,:)<=age_ub & adj_dummy(tw0,:,:)==k),wealth_pc(2));
    wealth_pc3 = prctile(wealth_cnt(tw0,age(tw0,:,:)>=age_lb & age(tw0,:,:)<=age_ub & adj_dummy(tw0,:,:)==k),wealth_pc(3));

    coh_slc_w(1,age(tw0,:,:)>=age_lb & age(tw0,:,:)<=age_ub & wealth_cnt(tw0,:,:)<=wealth_pc1) = 1;
    coh_slc_w(1,age(tw0,:,:)>=age_lb & age(tw0,:,:)<=age_ub & wealth_cnt(tw0,:,:)>wealth_pc1 & wealth_cnt(tw0,:,:)<=wealth_pc2 & adj_dummy(tw0,:,:)==k) = 2;
    coh_slc_w(1,age(tw0,:,:)>=age_lb & age(tw0,:,:)<=age_ub & wealth_cnt(tw0,:,:)>wealth_pc2 & wealth_cnt(tw0,:,:)<=wealth_pc3 & adj_dummy(tw0,:,:)==k) = 3;
    coh_slc_w(1,age(tw0,:,:)>=age_lb & age(tw0,:,:)<=age_ub & wealth_cnt(tw0,:,:)>wealth_pc3 & adj_dummy(tw0,:,:)==k) = 4;
    end

end

coh_slc_w = repmat(coh_slc_w,[size(age,1),1,1]);

% Set dead to zero
for i=1:yearN-year_p0+1
 t = i+t_p0-1;
 coh_slc_w(t,age(t,:,:)==-1)=0;
end

% From prediction yr1-end plus GR and PR mean
iex_mean = nan(yearN-year_p0+1+1,coh_w_gr);
val_mean=iex_mean;
adj_mean=iex_mean;
p_sav_mean=iex_mean;

iex_pred_mean =  nan(yearN-year_p0+1+1,coh_w_gr);
val_pred_mean=iex_mean;
adj_pred_mean=iex_mean;


% Construct means logs from model data for year_p0-end
for i=1:yearN-year_p0+1
    t = i+t_p0-1;
    for j=1:coh_w_gr
        iex_mean(i,j) = mean(iex(t,coh_slc_w(t,:,:)==j));
        val_mean(i,j) = mean(val(t,adj(t,:,:)==1 & coh_slc_w(t,:,:)==j));
        adj_mean(i,j) = mean(adj(t,coh_slc_w(t,:,:)==j));

        % Predicted
        iex_pred_mean(i,j) = mean(iex_pred(i,coh_slc_w(t,:,:)==j));
        val_pred_mean(i,j) = mean(val_pred(i,adj(t,:,:)==1 & coh_slc_w(t,:,:)==j));
        adj_pred_mean(i,j) = mean(adj_pred(i,coh_slc_w(t,:,:)==j));
    end
end


% Great Recession
t = dsearchn(time',year_gr(1)):dsearchn(time',year_gr(2));
i = t-t_p0+1;
D = zeros(size(age));
D(t,:,:) = coh_slc_w(t,:,:);
D_adj = D;
D_adj(adj==0)=0;

E = zeros(size(iex_pred));
E(i,:,:) = coh_slc_w(t,:,:);
E_adj = E;
E_adj(adj(t_p0:end,:,:)==0)=0;

for j=1:coh_w_gr
    iex_mean(end,j) = mean(iex(D==j));
    val_mean(end,j) = mean(val(D_adj==j));
    adj_mean(end,j) = mean(adj(D==j));

    % Predicted
    iex_pred_mean(end,j) = mean(iex_pred(E==j));
    val_pred_mean(end,j) = mean(val_pred(E_adj==j));
    adj_pred_mean(end,j) = mean(adj_pred(E==j));
end

yrs_print=1;
yprint = length(iex_mean);

iex_table = zeros(coh_w_gr,3);
val_table = iex_table;
adj_table = iex_table;

bs1 = 3;
bs2 = 4;

for j=1:coh_w_gr

    iex_table(j,1) = iex_mean(end,j)/iex_mean(bs1,j)-1;
    iex_table(j,2) = iex_pred_mean(end,j)/iex_pred_mean(bs1,j)-1;
    iex_table(j,3) = iex_table(j,1)-iex_table(j,2);

    val_table(j,1) = val_mean(end,j)/val_mean(bs1,j)-1;
    val_table(j,2) = val_pred_mean(end,j)/val_pred_mean(bs1,j)-1;
    val_table(j,3) = val_table(j,1)-val_table(j,2);

    adj_table(j,1) = adj_mean(end,j)-adj_mean(bs1,j);
    adj_table(j,2) = adj_pred_mean(end,j)-adj_pred_mean(bs1,j);
    adj_table(j,3) = adj_table(j,1)-adj_table(j,2);
end

cohort_out = [iex_table(:,3)';adj_table(:,3)';val_table(:,3)'];
mdl_base_edu = cohort_out;
save('out/cohort_out.mat','mdl_base','mdl_base_edu')

end
