MODULE share

  ! MODEL SELECT
  ! --------------
  LOGICAL, PARAMETER :: base_rate = .TRUE.
  LOGICAL, PARAMETER :: base_growth = .TRUE.

! PARAMETERS
! --------------
    REAL(8), PARAMETER :: psi=1.5d0
    REAL(8), PARAMETER :: r=1.04d0
    REAL(8), PARAMETER :: rk=1.d0 + 0.05783d0 - r
    REAL(8), PARAMETER :: zeta=0.6d0
    INTEGER, PARAMETER :: pen_yr=5
    REAL(8) :: u_ret
    INTEGER, PARAMETER :: twork = 40
    INTEGER, PARAMETER :: trest = 20

    REAL(8) :: tau, eta
    REAL(8), PARAMETER :: g_scale = 0.5664d0
    INTEGER, PARAMETER :: gnorm = 2
    REAL(8), PARAMETER :: g_dur = twork
    REAL(8) :: sigma_ar
    REAL(8), PARAMETER :: rho_rk = 0.4996d0
    REAL(8), PARAMETER :: sigma_rk = 0.2968d0
    REAL(8), PARAMETER :: m_rk = LOG( rk )


    REAL(8), PARAMETER :: ily_stdage1 = .5817765d0
    REAL(8), PARAMETER :: ily_age1 = -0.5d0 * ily_stdage1**2
    REAL(8), PARAMETER :: ik_age1 = 0.08563d0
    REAL(8), PARAMETER :: ik_stdage1 = 1.035768d0
    REAL(8), PARAMETER :: ild_age1 = -1.388311d0
    REAL(8), PARAMETER :: ild_stdage1 = 1.0390140

    ! Wealth parameters
    REAL(8), PARAMETER :: sigma_q_h = 0.0308d0
    REAL(8), PARAMETER :: sigma_q_s = 0.1327d0
    REAL(8), PARAMETER :: cov_q_hs = -0.00018d0

! Calibrated parameters
    REAL(8),PARAMETER :: sigma_cps=0.0224d0
    REAL(8),PARAMETER :: sigma_nipa=0.02116d0

    REAL(8),PARAMETER :: sigma_ma=0.2460d0
    REAL(8),PARAMETER :: sigma_id=0.14011d0
    REAL(8),PARAMETER :: sigma_pve = 0.007679477678818
    REAL(8), PARAMETER ::  corr_pve_v = 0.440066534088353
    REAL(8) :: sigma_ma_lc, beta_pve, sigma_pve_res

    REAL(8), PARAMETER :: p_adj_0 = .1963799d0

    REAL(8),PARAMETER :: theta=0.827011924106338d0
    REAL(8),PARAMETER :: kappa=1.14540840305835d0
    REAL(8),PARAMETER :: xi =0.723984681380191d0
    REAL(8),PARAMETER :: F=0.130156404337943d0
    REAL(8),PARAMETER :: gamma=0.183330606370360d0
    REAL(8),PARAMETER :: sigma_ag=0.0198759135023188d0
    REAL(8), PARAMETER :: gnodes_sc=1.d0
    REAL(8), PARAMETER :: beta=0.944115680568841d0

    REAL(8),PARAMETER :: delta_2=0.145860272229820d0
    REAL(8),PARAMETER :: delta_1=1.42186803203426* delta_2
    REAL(8),PARAMETER :: p_delta_2=0.85d0
    REAL(8),PARAMETER :: p_delta_1=1.d0
    REAL(8) :: m_delta


! GRIDS
! --------------
    REAL(8), parameter :: amin=0       !minimum asset value
    REAL(8), parameter :: amax=15.d0   !max asset
    REAL(8), parameter :: Dmin=0       !minimum durable choice
    REAL(8), parameter :: Dmax=2.d0   !maximum durable choice
    REAL(8), PARAMETER :: cover_e = 3.d0
    REAL(8), PARAMETER :: cover_u = 3.d0
    REAL(8), PARAMETER :: cover_w = 3.d0
    REAL(8), PARAMETER :: cover_rk = 3.d0
    REAL(8), parameter :: cmin = 1.d-7
    REAL(8), parameter :: vmin = -1.d7
    REAL(8) :: emin, emax, umin, umax, wmin, wmax, rkmin, rkmax
    REAL(8) :: zmin, zmax, xmin, xmax
    INTEGER, PARAMETER :: ng = trest+twork
    integer, parameter :: ne = 7  ! size of idiosyncratic labor shock grid (perm)
    integer, parameter :: nu = 5  ! size of idiosyncratic labor shock grid (transitory)
    integer, parameter :: nw = 5  ! size of price shocks grid
    integer, parameter :: nrk = 5 ! size or rate grid
    integer, parameter :: ngp = 2 ! size of growth rate grid
    INTEGER, PARAMETER :: ndp = 2  ! size of depreciation grid
    integer, parameter :: na = 200 ! size of asset grid
    integer, parameter :: nD = 150 ! size of durable grid
    integer, parameter :: nz = 250 ! size of resource grid (adjust)
    integer, parameter :: nx = 250 ! size of resource grid (adjust)

    REAL(8), DIMENSION(ne) :: enodes  !Nodes for idiosyncratic productivity (perm)
    REAL(8), DIMENSION(nu) :: unodes  !Nodes for idiosyncratic productivity (transitory)
    REAL(8), DIMENSION(ng) :: m_q_h, m_q_s, m_q, sigma_q, h_shr, s_shr
    REAL(8), DIMENSION(ndp) :: delta  !Nodes for depreciation
    REAL(8), DIMENSION(nw,ng) :: wnodes  !Nodes for asset price shocks
    REAL(8), DIMENSION(nrk) :: rknodes  !Nodes for rate spread
    REAL(8), DIMENSION(ng,ngp) :: gnodes
    REAL(8), DIMENSION(ng) :: betanodes, eqvnodes  !Nodes for lifecycle profile
    REAL(8), DIMENSION(na) :: anodes  !Nodes for idiosyncratic assets
    REAL(8), DIMENSION(nD) :: Dnodes  !Nodes for idiosyncratic durables
    INTEGER, DIMENSION(nD) :: Dpnodes  !Nodes for idiosyncratic durable
    REAL(8), DIMENSION(nz) :: znodes
    REAL(8), DIMENSION(nx) :: xnodes
    REAL(8), DIMENSION(ne,ne) :: Probe, Probecum !Transition probabilities for idiosyncratic productivity (perm)
    REAL(8), DIMENSION(nu,nu) :: Probu, Probucum !Transition probabilities for idiosyncratic productivity (transitory)
    REAL(8), DIMENSION(nw,nw,ng) :: Probw, Probwcum !Transition probabilities for price shocks
    REAL(8), DIMENSION(nrk,nrk) :: Probrk, Probrkcum
    REAL(8), DIMENSION(ngp,ngp) :: Probg
    REAL(8), DIMENSION(ndp,ndp) :: Probdp, Probdpcum  !Transition probabilities for depreciation rate

! SIMULATION
! --------------
    INTEGER, PARAMETER :: numsim=4000  !Length of simulation
    INTEGER, PARAMETER :: simlives = numsim / ng + 2
    INTEGER, PARAMETER :: agent_age = 2000       ! Number of agents of each age
    INTEGER, PARAMETER :: agents= ng*agent_age
    INTEGER, PARAMETER :: burnin=ng+1    !Initial periods dropped in simulation
    REAL(8), PARAMETER :: p_adj_0_tune = 1.5d0

! LIFECYCLE
! -------------
    INTEGER, PARAMETER :: indi_str = 500

! SHOCKS
! --------------
    INTEGER, PARAMETER :: rep = 150
    INTEGER, PARAMETER :: rep_out = 150
    INTEGER, PARAMETER :: agents_out_sc = 2
    INTEGER, PARAMETER :: agents_out = FLOOR(DBLE(agents)/DBLE(agents_out_sc))
    INTEGER, PARAMETER :: shck_c = 5
    INTEGER, PARAMETER :: numshock=2*ng
    INTEGER, PARAMETER :: shocklives = numshock / ng + 2
    INTEGER, PARAMETER :: yr1_shock = 1946
    INTEGER, PARAMETER :: yr_end_shock = 2018
    INTEGER, PARAMETER :: shockseries1_n = 89
    REAL(8), DIMENSION(shockseries1_n) :: shockseries1
    INTEGER, PARAMETER :: shockseries2_h_n = 43
    REAL(8), DIMENSION(shockseries2_h_n) :: shockseries2_h
    INTEGER, PARAMETER :: shockseries2_s_n = 58
    REAL(8), DIMENSION(shockseries2_s_n) :: shockseries2_s
    INTEGER, PARAMETER :: shockseries3_n = 46
    REAL(8), DIMENSION(shockseries3_n) :: shockseries3

    INTEGER, PARAMETER :: shockseries1_start = yr_end_shock+1-yr1_shock
    INTEGER, PARAMETER :: shck_c_period = yr_end_shock+1-2007
    INTEGER, PARAMETER :: g_shck_period = yr_end_shock+1-2009
    REAL(8), DIMENSION(g_shck_period,twork) :: g_shck_ageprofile

! Cohort shocks
! ---
    INTEGER, PARAMETER :: coh_size = 10
    INTEGER, PARAMETER :: shockseriescoh_n    = 56
    REAL(8), DIMENSION(shockseriescoh_n,twork) :: shockseriescoh, unempseriescoh
    REAL(8), DIMENSION(shockseriescoh_n) :: shockseriescoh_agg, unempseriescoh_agg
    INTEGER, PARAMETER :: coh_fe_n = 56
    REAL(8), DIMENSION(coh_fe_n) :: coh_fe
    INTEGER, PARAMETER :: shockseriesmat_n = yr_end_shock-1980+1

! SHOCKS
! --------------
    INTEGER, PARAMETER :: rep_irf=100
    INTEGER, PARAMETER :: irf_exp_c = 7
    INTEGER, PARAMETER :: irf_v_i = 2
    INTEGER, PARAMETER :: irf_m_i = 3
    INTEGER, PARAMETER :: irf_w_i = 4
    INTEGER, PARAMETER :: irf_g_i = 5
    INTEGER, PARAMETER :: irf_r_i = 6
    INTEGER, PARAMETER :: irf_nr_i = 7
    INTEGER, PARAMETER :: irf_gr_i = 8
    INTEGER, PARAMETER :: coh_out = 4
    INTEGER, PARAMETER :: irf_coh_c = coh_out+1
    INTEGER, PARAMETER :: irf_c = irf_exp_c+1
    INTEGER, PARAMETER :: irf_len = 6
    INTEGER, PARAMETER :: numirf=ng+irf_len
    INTEGER, PARAMETER :: irflives = 3
    REAL, PARAMETER :: sigma_wealth_irf = -0.39132869281786820d0

END MODULE share
