close all
clear all
clc

% DATA see file: replication_kit\empiricalcexcohort_data.do
data_cex = csvread('../empirical/figure4/cohort_cex_data.csv',1,0);
data_cex_edu =  csvread('../empirical/figure4/cohort_cex_data_education.csv',1,0);

% MODEL
FileName_uniinc = fullfile('./income_only/out',  'cohort_income_out.mat');
FileName_base = fullfile('./full_model/out',  'cohort_out.mat');

load(FileName_uniinc);
load(FileName_base);

fnt_sz = 16;
fnt_sz2 = 12;
wd = 0.90;

% DATA
data_cgr = data_cex(:,1);
data_iexts = data_cex(:,2);
data_p_buy = data_cex(:,3);
data_val = data_cex(:,4);
data_p_save = data_cex(:,5);
data_cloan = data_cex(:,6);

data_edu_iexts = data_cex_edu(:,1);
data_edu_p_buy = data_cex_edu(:,2);
data_edu_val =data_cex_edu(:,3);

% MODEL
uni_cgr = mdl_uni(1,:);
uni_iexts = mdl_uni(2,:);
uni_p_buy = mdl_uni(3,:);
uni_val = mdl_uni(4,:);
uni_p_save = mdl_uni(5,:);
uni_cloan = mdl_uni(6,:);

coh_cgr = mdl_coh(1,:);
coh_iexts = mdl_coh(2,:);
coh_p_buy = mdl_coh(3,:);
coh_val = mdl_coh(4,:);
coh_p_save = mdl_coh(5,:);
coh_cloan = mdl_coh(6,:);

base_cgr = mdl_base(1,:);
base_iexts = mdl_base(2,:);
base_p_buy = mdl_base(3,:);
base_val = mdl_base(4,:);
base_p_save = mdl_base(5,:);
base_cloan = mdl_base(6,:);

% Wealth / Education comparison
base_edu_iexts = mdl_base_edu(1,:);
base_edu_p_buy = mdl_base_edu(2,:);
base_edu_val = mdl_base_edu(3,:);

c1 = categorical({'25-34','35-44','45-54'});   

cw = {'\fontsize{10}{wealth<0}','\fontsize{10}{   0-32pc\newline(wealth\geq0)}','\fontsize{10}{  33-65pc\newline(wealth\geq0)}','\fontsize{10}{  66-100pc\newline(wealth\geq0)}'};
ce = {'\fontsize{10}{drop out\newline(0-11pc)}','\fontsize{10}{high school\newline  (12-37pc)}','\fontsize{10}{some college\newline  (38-66pc)}','\fontsize{10}{  college\newline(67-100pc)}'};  


f1=figure(1);
bar(c1,100*[data_iexts';uni_iexts;coh_iexts;base_iexts]',wd)
legend('Data','Uniform','Cohort','Baseline','Location','SouthEast','FontSize',fnt_sz2)   
set(gca,'FontSize',fnt_sz)
ylabel('% deviation')
ylim([-35 0])
set(f1,'Name','Car expenditure')

f1 = figure(2);  
bar(c1,100*[data_p_buy';uni_p_buy;coh_p_buy;base_p_buy]',wd)
set(gca,'FontSize',fnt_sz)
ylabel('p.p. deviation')
set(f1,'Name','Probability of purchase')

f1 = figure(3);    
bar(c1,100*[data_val';uni_val;coh_val;base_val]',wd)
set(gca,'FontSize',fnt_sz)
ylabel('% deviation')
set(f1,'Name','Value | purchase')

f1 = figure(4)   ;
bar(c1,100*[data_cgr';uni_cgr;coh_cgr;base_cgr]',wd)    
set(gca,'FontSize',fnt_sz)
ylabel('p.p. deviation')
set(f1,'Name','Consumption growth')


f1 = figure(5);   
bar(c1,100*[data_p_save';uni_p_save;coh_p_save;base_p_save]',wd)
set(gca,'FontSize',fnt_sz)
ylabel('p.p. deviation')
set(f1,'Name','Share saving')

f1 = figure(6);  
bar(c1,100*[data_cloan';uni_cloan;coh_cloan;base_cloan]',wd)   
set(gca,'FontSize',fnt_sz)
%title('car loan ')
ylabel('% deviation')
set(f1,'Name','Car loans')

% EDUCATION
f1 = figure(7);  
bar(100*[data_edu_iexts';base_edu_iexts]',wd)
legend('Data','Baseline','Location','SouthEast','FontSize',fnt_sz2)  
set(gca,'XTickLabelRotation',0)
set(gca,'FontSize',fnt_sz)
set(gca, 'XTickLabels', ce);  
%title('car expenditure ')
ylabel('% deviation')
set(gca, 'OuterPosition', [0, 0.02, 1, 0.98]);
set(f1,'Name','Car expenditure (by education/wealth)')

f1 = figure(8);  
bar(100*[data_edu_p_buy';base_edu_p_buy]',wd)
set(gca,'XTickLabelRotation',0)
set(gca,'FontSize',fnt_sz)
set(gca, 'XTickLabels', ce);  
%title('% purchase')
ylabel('p.p. deviation')
set(gca, 'OuterPosition', [0, 0.02, 1, 0.98]);
set(f1,'Name','Probability of purchase (by education/wealth)')

f1 = figure(9);    
bar(100*[data_edu_val';base_edu_val]',wd)
set(gca,'FontSize',fnt_sz)
set(gca,'XTickLabelRotation',0)
set(gca, 'XTickLabels', ce);  
%title('car value | purchase')
ylabel('% deviation')
set(gca, 'OuterPosition', [0, 0.02, 1, 0.98]);
set(f1,'Name','Value | purchase (by education/wealth)')