clear all
clc
close all

datain = load('full_model/out/policy.txt');
V_n = datain(:,1);
V_a = datain(:,2);
D_a = datain(:,3);

% BASELINE MODEL SOLUTION
nx = 250;
nd = 150;

% GRID SIZED USED TO EXACTLY REPLICATE FIGURE 6
% nx = 300; 
% nd = 302; 

ndp = 2;
ngp = 2;
nrk = 5;

delta = 0.14586; 
gamma = 0.18333;
sigma_ma = 0.2460;
F = 0.1301564;
r = 1.04;
rk = 0.05783 - 0.04;
twork = 40;
trest = 20;

ng = trest+twork;
adj_tol = 1e-4;

eta = (1-delta-F)/(r+rk);
x = linspace( 0.47789725738351263,21.214507728112142,nx)';

d = linspace(0,2,nd)';
D_n = (1-delta*(1-gamma)) * repmat(kron(d,ones(ng*ndp*ngp*nrk,1)),nx,1);
adj = V_a>=V_n-adj_tol;
D_ch = D_a.*adj + D_n.*(~adj);

D_a = reshape(D_a,nrk,ngp,ndp,ng,nd,nx);
D_ch = reshape(D_ch,nrk,ngp,ndp,ng,nd,nx);

m_d = .5;
m_x = 1;
n_rk = 3;
max_x = 5;

lo_x = 0.4;
hi_x = 2;

i_d = dsearchn(d,m_d);
i_a = dsearchn(x,m_x);
i_a_l = dsearchn(x,lo_x);
i_a_h = dsearchn(x,hi_x);
i_x = dsearchn(x,max_x);
i_dp = 2;

% Income Shock
shk = 0.9;
m_a = 2;

m_a_bf = r*m_a +(1-delta)*m_d + 1;
m_a_af = r*m_a/shk +(1-delta)*m_d/shk + 1;
m_d_af = m_d/shk;

min_a = 0;
max_a = 7;
min_x_bf = min_a*(r+rk) + (1-delta-eta*(r+rk) )*m_d + (1-3*sigma_ma);
min_x_af = min_a/shk*(r+rk) + (1-delta-eta*(r+rk) )*m_d/shk + (1-3*sigma_ma);
max_x_bf = max_a*r + (1-delta-eta*r)*m_d + (1+3*sigma_ma);
max_x_af = max_a/shk*r + (1-delta-eta*r)*m_d/shk + (1+3*sigma_ma);

min_d_bf = 0;
min_d_af = min_d_bf/shk;
max_d_bf = shk*d(end);
max_d_af = max_d_bf/shk;

i_a_bf = dsearchn(x,m_a_bf);
i_a_af = dsearchn(x,m_a_af);
i_d_af = dsearchn(d,m_d_af);

i_min_x_bf = dsearchn(x,min_x_bf);
i_min_x_af = dsearchn(x,min_x_af);
i_max_x_bf = dsearchn(x,max_x_bf);
i_max_x_af = dsearchn(x,max_x_af);
i_min_d_bf = dsearchn(d,min_d_bf);
i_min_d_af = dsearchn(d,min_d_af);
i_max_d_bf = dsearchn(d,max_d_bf);
i_max_d_af = dsearchn(d,max_d_af);

x_bf = x(i_min_x_bf:i_max_x_bf);
x_af = linspace(x_bf(1),x_bf(end),i_max_x_af-i_min_x_af+1)';
d_bf = d(i_min_d_bf:i_max_d_bf);
d_af = linspace(d_bf(1),d_bf(end),i_max_d_af-i_min_d_af+1)';

i_age_l = 1;
i_age_m = twork-10;  
i_age_h = twork+trest-5;  

ln_wd = 4;
fnt_sz = 16;

figure(1)
hold on
plot(d,squeeze(D_ch(n_rk,ngp,i_dp,i_age_l,:,i_a_l)),'-r','LineWidth',ln_wd)
plot(d,squeeze(D_ch(n_rk,ngp,i_dp,i_age_m,:,i_a)),'-b','LineWidth',ln_wd)
plot(d,squeeze(D_ch(n_rk,ngp,i_dp,i_age_h,:,i_a_h)),'-k','LineWidth',ln_wd)
plot(d,squeeze(D_a(n_rk,ngp,i_dp,i_age_l,:,i_a_l)),'--r','LineWidth',ln_wd)
plot(d,squeeze(D_a(n_rk,ngp,i_dp,i_age_m,:,i_a)),'--b','LineWidth',ln_wd)
plot(d,squeeze(D_a(n_rk,ngp,i_dp,i_age_h,:,i_a_h)),'--k','LineWidth',ln_wd)  
hold off
set(gca,'FontSize',fnt_sz)
legend('age:young','age:mid','age:old','Location','NorthWest') 
xlabel('car stock')
ylabel('car choice')
axis tight


figure(2)
hold on
plot(d_bf,squeeze(D_ch(n_rk,ngp,i_dp,i_age_m,i_min_d_bf:i_max_d_bf,i_a_bf)),'-b','LineWidth',ln_wd)
plot(d_af,squeeze(shk*D_ch(n_rk,ngp,i_dp,i_age_m,i_min_d_af:i_max_d_af,i_a_af)),'-r','LineWidth',ln_wd)
hold off
set(gca,'FontSize',fnt_sz)
legend('Before','After: 10% negative shock','Location','NorthWest') 
axis([0 1.2 0.4 1.4])
xlabel('car stock')
ylabel('car choice')
