clear all
clc
close all

data = load('full_model/out/Irf_agg.txt'); 
data_coh = load('full_model/out/Irf_coh.txt'); 
data_unc = load('uncertainty_model/out/Irf_agg_unc.txt'); 

twork = 40;
trest = 20;
ng = twork+trest;

irf_len = 6;
num_irf = ng+irf_len;
irf0 = ng;
irfN = num_irf-1;
irfN2 = num_irf;

% Shock simulate parameters
rep = 100;
irf_exp_c=7;
irf_c = irf_exp_c+1;
coh_out = 4;

irf_unc_exp_c=2;
irf_unc_c=irf_unc_exp_c+1;

% Shock locations
irf_v_i = 2;            
irf_m_i = 3;
irf_w_i = 4;
irf_g_i = 5;
irf_r_i = 6;
irf_nr_i = 7;
irf_gr_i = 8;

irf_unc_i = 3;

time = -ng+1:irf_len;

% Aggregate
cts = data(1,:);
its = data(2,:);
iexts = data(3,:);
newcar = data(4,:);
valnewcar = data(5,:);
wts = data(6,:);
val_cts = data(7,:);

% Cohort
its_coh = data_coh(1,:);
sav_coh = data_coh(2,:);
inc_coh = data_coh(3,:);
valnewcar2_coh = data_coh(4,:);
adjust_coh = data_coh(5,:);
maintts_coh = data_coh(6,:);

% Uncertainty model
cts_unc = data_unc(1,:);
its_unc = data_unc(2,:);
valnewcar_unc = data_unc(3,:);
wts_unc = data_unc(4,:);

cts = reshape(cts,num_irf,rep,irf_c);
its = reshape(its,num_irf,rep,irf_c);
iexts = reshape(iexts,num_irf,rep,irf_c);
newcar = reshape(newcar,num_irf,rep,irf_c);
valnewcar = reshape(valnewcar,num_irf,rep,irf_c);
wts = reshape(wts,num_irf,rep,irf_c);
val_cts = reshape(val_cts,num_irf,rep,irf_c);

its_coh = reshape(its_coh,num_irf,rep,irf_c,coh_out);
sav_coh = reshape(sav_coh,num_irf,rep,irf_c,coh_out);
inc_coh = reshape(inc_coh,num_irf,rep,irf_c,coh_out);
valnewcar2_coh = reshape(valnewcar2_coh,num_irf,rep,irf_c,coh_out);
adjust_coh =  reshape(adjust_coh,num_irf,rep,irf_c,coh_out);
maintts_coh =  reshape(maintts_coh,num_irf,rep,irf_c,coh_out);

cts_unc = reshape(cts_unc,num_irf,rep,irf_unc_c);
its_unc = reshape(its_unc,num_irf,rep,irf_unc_c);
valnewcar_unc = reshape(valnewcar_unc,num_irf,rep,irf_unc_c);
wts_unc = reshape(wts_unc,num_irf,rep,irf_unc_c);

% Longer series
its_long = its;
iexts_long = iexts;
val_cts_long = val_cts;
its_coh_long = its_coh;

sav_r_coh = sav_coh./inc_coh;

% IEXTS decomposition
iexts_dcmp_ext = newcar.*repmat(valnewcar(:,:,1),[1,1,irf_c]);
iexts_dcmp_int = repmat(newcar(:,:,1),[1,1,irf_c]).*valnewcar;

% ITS decomposition, cohorts (full extensive margin)
its_dcmp_ext_coh = (1-adjust_coh).*repmat(maintts_coh(:,:,1,:),[1,1,irf_c,1]) + adjust_coh.*repmat(valnewcar2_coh(:,:,1,:),[1,1,irf_c,1]);
its_dcmp_int_coh = ( 1-repmat(adjust_coh(:,:,1,:),[1,1,irf_c,1]) ).*repmat(maintts_coh(:,:,1,:),[1,1,irf_c,1]) + repmat(adjust_coh(:,:,1,:),[1,1,irf_c,1]).*valnewcar2_coh;

% Reshape and take average
time2 = time(irf0:irfN2);
time = time(irf0:irfN);

cts = squeeze(mean(log(cts(irf0:irfN,:,:)),2));
its =  squeeze(mean(log(its(irf0:irfN,:,:)),2));
iexts =  squeeze(mean(log(iexts(irf0:irfN,:,:)),2));
valnewcar =  squeeze(mean(log(valnewcar(irf0:irfN,:,:)),2));
wts =  squeeze(mean(log(wts(irf0:irfN,:,:)),2));

iexts_dcmp_ext =  squeeze(mean(log(iexts_dcmp_ext(irf0:irfN2,:,:)),2));
iexts_dcmp_int =  squeeze(mean(log(iexts_dcmp_int(irf0:irfN2,:,:)),2));

its_coh =  squeeze(mean(log(its_coh(irf0:irfN,:,:,:)),2));
sav_r_coh =  squeeze(mean(sav_r_coh(irf0:irfN,:,:,:),2));
its_dcmp_ext_coh =  squeeze(mean(log(its_dcmp_ext_coh(irf0:irfN2,:,:,:)),2));
its_dcmp_int_coh =  squeeze(mean(log(its_dcmp_int_coh(irf0:irfN2,:,:,:)),2));

iexts_long =  squeeze(mean(log(iexts_long(irf0:irfN2,:,:)),2));
val_cts_long =  squeeze(mean(val_cts_long(irf0:irfN2,:,:),2));
its_coh_long =  squeeze(mean(log(its_coh_long(irf0:irfN2,:,:,:)),2));

cts_unc = squeeze(mean(log(cts_unc(irf0:irfN,:,:)),2));
its_unc =  squeeze(mean(log(its_unc(irf0:irfN,:,:)),2));
wts_unc =  squeeze(mean(log(wts_unc(irf0:irfN,:,:)),2));
valnewcar_unc =  squeeze(mean(log(valnewcar_unc(irf0:irfN,:,:)),2));

% Deviation from s.s.
irf_cts = cts-repmat(cts(:,1),1,irf_c);
irf_its =  its-repmat(its(:,1),1,irf_c);
irf_valnewcar =  valnewcar-repmat(valnewcar(:,1),1,irf_c);
irf_wts =  wts-repmat(wts(:,1),1,irf_c);

irf_iexts_dcmp_ext =  iexts_dcmp_ext-repmat(iexts_dcmp_ext(:,1),1,irf_c);
irf_iexts_dcmp_int =  iexts_dcmp_int-repmat(iexts_dcmp_int(:,1),1,irf_c);

irf_its_coh =  its_coh-repmat(its_coh(:,1,:),[1,irf_c,1]);
irf_sav_r_coh =  sav_r_coh-repmat(sav_r_coh(:,1,:),[1,irf_c,1]);
irf_its_dcmp_ext_coh =  its_dcmp_ext_coh-repmat(its_dcmp_ext_coh(:,1,:),[1,irf_c,1]);
irf_its_dcmp_int_coh =  its_dcmp_int_coh-repmat(its_dcmp_int_coh(:,1,:),[1,irf_c,1]);

irf_iexts_long =  iexts_long-repmat(iexts_long(:,1),1,irf_c);
irf_val_cts_long =  val_cts_long-repmat(val_cts_long(:,1),1,irf_c);
irf_its_coh_long =  its_coh_long-repmat(its_coh_long(:,1,:),[1,irf_c,1]);

irf_cts_unc = cts_unc-repmat(cts_unc(:,1),1,irf_unc_c);
irf_its_unc =  its_unc-repmat(its_unc(:,1),1,irf_unc_c);
irf_wts_unc =  wts_unc-repmat(wts_unc(:,1),1,irf_unc_c);
irf_valnewcar_unc = valnewcar_unc-repmat(valnewcar_unc(:,1),1,irf_unc_c);

% ITS Decomposition
xx = zeros(size(irf_its_dcmp_ext_coh));
irf_its_dcmp_extPLint_coh = (sign(irf_its_dcmp_ext_coh)==sign(irf_its_dcmp_int_coh)).*(irf_its_dcmp_ext_coh + irf_its_dcmp_int_coh) + ...
    (sign(irf_its_dcmp_ext_coh)~=sign(irf_its_dcmp_int_coh)).*(irf_its_dcmp_int_coh);
irf_its_dcmp_miss_coh = irf_its_coh_long - (irf_its_dcmp_ext_coh + irf_its_dcmp_int_coh);
irf_its_dcmp_oth_coh  = (irf_its_dcmp_miss_coh>0).*(irf_its_dcmp_miss_coh+max(max(irf_its_dcmp_ext_coh,irf_its_dcmp_extPLint_coh),xx) ) + ...
    (irf_its_dcmp_miss_coh<0).*(irf_its_dcmp_miss_coh+min(min(irf_its_dcmp_ext_coh,irf_its_dcmp_extPLint_coh),xx) );

% IEXTS Decomposition
xx = zeros(size(irf_iexts_dcmp_ext));
irf_iexts_dcmp_extPLint = (sign(irf_iexts_dcmp_ext)==sign(irf_iexts_dcmp_int)).*(irf_iexts_dcmp_ext + irf_iexts_dcmp_int) + ...
    (sign(irf_iexts_dcmp_ext)~=sign(irf_iexts_dcmp_int)).*(irf_iexts_dcmp_int);
irf_iexts_dcmp_miss = irf_iexts_long - (irf_iexts_dcmp_ext + irf_iexts_dcmp_int);
irf_iexts_dcmp_oth  = (irf_iexts_dcmp_miss>0).*(irf_iexts_dcmp_miss+max(max(irf_iexts_dcmp_ext,irf_iexts_dcmp_extPLint),xx)   ) + ...
    (irf_iexts_dcmp_miss<0).*(irf_iexts_dcmp_miss+min(min(irf_iexts_dcmp_ext,irf_iexts_dcmp_extPLint),xx) );

x1 = [time2, fliplr(time2)];

% CAR INVESTMENT
inBetween_iexts_ext = [irf_iexts_dcmp_ext',zeros(irf_c,length(time2))];
inBetween_iexts_int = [irf_iexts_dcmp_extPLint',zeros(irf_c,length(time2))];
inBetween_iexts_oth = [irf_iexts_dcmp_oth',zeros(irf_c,length(time2))];

% COHORT CAR INVESTMENT
inBetween_its_ext_coh       = zeros(irf_c,2*length(time2),coh_out);
inBetween_its_int_coh       = inBetween_its_ext_coh;
inBetween_its_oth_coh       = inBetween_its_ext_coh;

for i=1:coh_out
inBetween_its_ext_coh(:,:,i) = [irf_its_dcmp_ext_coh(:,:,i)',zeros(irf_c,length(time2))];
inBetween_its_int_coh(:,:,i) = [irf_its_dcmp_extPLint_coh(:,:,i)',zeros(irf_c,length(time2))];
inBetween_its_oth_coh(:,:,i) = [irf_its_dcmp_oth_coh(:,:,i)',zeros(irf_c,length(time2))];
end

INTX_SHARE = irf_iexts_dcmp_int(2:end,:)./irf_iexts_long(2:end,:);

fnt_sz=14;
fnt_sz2 = 10;
fnt_sz_leg=10;
ln_wd = 1.5;
ln_wd2 = 1;
ln_wd3 = 2;
ln_wd4 = 4;

ext_c = [0.4 0.4 1]; % CI color (blue)
int_c = [1 0.4 0.4]; % CI color (red)
stk_c = [0.6 0.6 0.6]; % CI color (Grey)
oth_c = [0.7 0.7 0.7]; % CI color (Grey)


pick_irf = [irf_m_i, irf_v_i, irf_w_i, irf_g_i, irf_r_i];
irftitle = {'transitory income','permanent income','wealth','life-cycle profile','car loan premium'};
pick_irf2 =[irf_nr_i,irf_gr_i];
irftitle2 ={'normal recession','Great Recession'};

n_coh_irf = 2;
gc = zeros(1,n_coh_irf);
pick_irf_coh2 = [irf_g_i,irf_v_i];
mx_coh = 4;
cohtitle2 = {'25-34','35-44','45-54','55-64'};
irf_c2 = {'b','r'};


for irf_loop2=1:5
f1=figure(irf_loop2);
hold on
g1=plot(time,100*irf_cts(:,pick_irf(irf_loop2)),'-b','LineWidth',ln_wd4);
g2=plot(time,100*irf_valnewcar(:,pick_irf(irf_loop2)),'--r','LineWidth',ln_wd4);
g3=plot(time,100*irf_its(:,pick_irf(irf_loop2)),'-r','LineWidth',ln_wd4);
g4=plot(time,100*irf_wts(:,pick_irf(irf_loop2)),'-k','LineWidth',ln_wd4);
plot(time,zeros(size(time)),'-k','LineWidth',ln_wd2)
hold off
set(gca,'FontSize',fnt_sz)
ylabel('%')
set(gcf,'Name',irftitle{irf_loop2} )
h1.YAxis.Exponent = 0;
axis tight

if irf_loop2==1
       legend([g1,g2,g3,g4],{'consumption','value|purchase','car expenditure','income'},'Location','SouthEast') 

end
end

f1=figure(6);
hold on
g1=plot(time,100*irf_cts_unc(:,irf_unc_i),'-b','LineWidth',ln_wd4);
g2=plot(time,100*irf_valnewcar_unc(:,irf_unc_i),'--r','LineWidth',ln_wd4);
g3=plot(time,100*irf_its_unc(:,irf_unc_i),'-r','LineWidth',ln_wd4);
g4=plot(time,100*irf_wts_unc(:,irf_unc_i),'-k','LineWidth',ln_wd4);
plot(time,zeros(size(time)),'-k','LineWidth',ln_wd2)
hold off
set(gca,'FontSize',fnt_sz)
ylabel('%')
set(gcf,'Name','Uncertainty' )
h1.YAxis.Exponent = 0;
axis tight


bloc = 100*irf_sav_r_coh(:,pick_irf_coh2(1:n_coh_irf),1:mx_coh);
mn_y = min(bloc(:));
mx_y = max(bloc(:));

f1=figure(7);
for coh_loop=1:mx_coh
h1=subplot(2,2,coh_loop);
hold on
for irf_loop2=1:n_coh_irf 
gc(irf_loop2)=plot(time,100*irf_sav_r_coh(:,pick_irf_coh2(irf_loop2),coh_loop),irf_c2{irf_loop2},'LineWidth',ln_wd4);
end
plot(time,zeros(size(time)),'-k','LineWidth',ln_wd2)
hold off
set(gca,'FontSize',fnt_sz2)
ylabel('p.p.')
title(cohtitle2{coh_loop})
if coh_loop==mx_coh
    legend([gc],{'life cycle profile','permanent income'},'Location','NorthEast') 
end
axis([time(1), time(end), mn_y, mx_y]);   
end
set(gcf,'Name','Cohort saving response' )

pick_irf_coh1 = [irf_g_i,irf_w_i];
mx_coh2=3;
cohtitle3 = {'profile (25-34)','profile (45-54)','wealth (25-34)','wealth (45-54)'};

f1=figure(8);
pick_irf_coh1 = [irf_g_i,irf_w_i];
for irf_loop2=1:n_coh_irf   
    bloc = 100*[squeeze(irf_its_dcmp_ext_coh(1:end-(irfN2-irfN),pick_irf_coh1(irf_loop2),1:mx_coh2)); ...
        squeeze(irf_its_dcmp_extPLint_coh(1:end-(irfN2-irfN),pick_irf_coh1(irf_loop2),1:mx_coh2)); ...
        squeeze(irf_its_coh(:,pick_irf_coh1(irf_loop2),1:mx_coh2))];
    mn_y = min(bloc(:));
    mx_y = max(bloc(:));
    for coh_loop=1:2:mx_coh2
    index = (irf_loop2-1)*2+(coh_loop-1)/2+1; 
    h1=subplot( 2 , 2,index );
    hold on
    g3=fill(x1,100*inBetween_its_oth_coh(pick_irf_coh1(irf_loop2),:,coh_loop),oth_c,'EdgeColor','none');
    g2=fill(x1,100*inBetween_its_int_coh(pick_irf_coh1(irf_loop2),:,coh_loop),int_c,'EdgeColor','none');
    g1=fill(x1,100*inBetween_its_ext_coh(pick_irf_coh1(irf_loop2),:,coh_loop),ext_c,'EdgeColor','none');
    g4=plot(time,100*irf_its_coh(:,pick_irf_coh1(irf_loop2),coh_loop),'-k','LineWidth',ln_wd3);
    plot(time2,zeros(size(time2)),'-k','LineWidth',ln_wd2)
    hold off
    set(gca,'FontSize',fnt_sz2)
    ylabel('%')
    %axis tight
    axis([time(1), time(end), mn_y, mx_y]);    
    title(cohtitle3{index})
    if irf_loop2==1 && coh_loop==mx_coh2
        legend([g1,g2,g3,g4],{'extensive','intensive','other','aggregate'},'Location','SouthEast') 
    end
    end
end
set(gcf,'Name','Cohort car expenditure response' )

bloc = 100*[squeeze(irf_iexts_dcmp_ext(:,pick_irf2)); ...
    squeeze(irf_iexts_dcmp_extPLint(:,pick_irf2)); ...
    squeeze(irf_iexts_long(:,pick_irf2))];
mn_y = min(bloc(:));
mx_y = max(bloc(:));
for irf_loop2=1:2
f1=figure(8+irf_loop2);
%h1=subplot(1,2,irf_loop2);
hold on
g2=fill(x1,100*inBetween_iexts_int(pick_irf2(irf_loop2),:),int_c,'EdgeColor','none');
g1=fill(x1,100*inBetween_iexts_ext(pick_irf2(irf_loop2),:),ext_c,'EdgeColor','none');
g4=plot(time2,100*irf_iexts_long(:,pick_irf2(irf_loop2)),'-k','LineWidth',ln_wd3);
plot(time2,zeros(size(time2)),'-k','LineWidth',ln_wd2)
hold off
set(gca,'FontSize',fnt_sz)
ylabel('%')
axis([time(1), time2(end), mn_y*1.05, mx_y]);   
temp1 = 100*inBetween_iexts_ext(pick_irf2(irf_loop2),2);
temp2 = 100*inBetween_iexts_int(pick_irf2(irf_loop2),2) ;
%g5=line([1 1], [temp2,temp1],'Color','k','LineStyle','--','LineWidth',1.5,'Marker','_'); % ,'square');
g5=line([1 1], [temp2,temp1],'Color','k','LineStyle','--','LineWidth',1.5,'Marker','square');
if irf_loop2==1
div = 5;
else
div = 2;    
end
text(1.05, temp1+(temp2-temp1)/div, [num2str(100*INTX_SHARE(1,pick_irf2(irf_loop2)),'%.1f'),'%'],'FontSize',fnt_sz);
if irf_loop2==1
    legend([g1,g2,g4],{'extensive','intensive','aggregate'},'Location','SouthEast') 
end
set(gcf,'Name',['Car investment (IEXTS) decomposition: ',irftitle2{irf_loop2}])
end

nr_end = 6; 

% CEX data
data_v_c = [0,-0.000384780043417382,0.00715312657983193,-0.000367674296918780,0.00808786399299719,-0.0131019918837535,-0.0106207302605042;
    0,0.00382360578991597,-0.0198305384201681,-0.0523882826302521,-0.0631508768403362,-0.0477646460504202,-0.0621480902605042];

% Adjust GR for value:cts
data_v_c_gr_adj = data_v_c(2,2:end)-data_v_c(2,2);

f1=figure(11);
bloc = 100*[data_v_c(1,:)';data_v_c_gr_adj';irf_val_cts_long(1:nr_end ,irf_nr_i);irf_val_cts_long(:,irf_gr_i)];
mn_y = min(bloc(:));
mx_y = max(bloc(:));

hold on
g1=plot(time2(1:nr_end ),100*irf_val_cts_long(1:nr_end ,irf_nr_i),'b','LineWidth',ln_wd4);
g2=plot(time2,100*irf_val_cts_long(:,irf_gr_i),'r','LineWidth',ln_wd4);
g3=plot(time2(1:nr_end ), 100*data_v_c(1,1:nr_end),'--b','LineWidth',ln_wd4);
g4=plot(time2(1:end-1), 100*data_v_c_gr_adj,'--r','LineWidth',ln_wd4);
plot(time2,zeros(size(time2)),'-k','LineWidth',ln_wd2)
hold off
ylabel('p.p.')
axis([time(1), time2(end), mn_y, mx_y+2]);
set(gca,'FontSize',fnt_sz)
legend([g1,g3,g2,g4],{'Normal (model)','Normal (data)',...
    'Great Recession (model)','Great Recession (data)'},'Location','NorthWest','FontSize',10)
set(gcf,'Name','value:non-durables | purchase')




