MODULE share

! PARAMETERS
! --------------
    REAL(8), PARAMETER :: psi=1.5d0
    REAL(8), PARAMETER :: r=1.04d0
    REAL(8), PARAMETER :: rk=1.d0 + 0.05783d0 - r
    REAL(8), PARAMETER :: zeta=0.6d0

    INTEGER, PARAMETER :: pen_yr=5
    REAL(8) :: u_ret
    INTEGER, PARAMETER :: twork = 40
    INTEGER, PARAMETER :: trest = 20

    REAL(8) :: tau, eta
    INTEGER, PARAMETER :: snorm = 2

    REAL(8), PARAMETER :: ily_stdage1 = .5817765d0
    REAL(8), PARAMETER :: ily_age1 = -0.5d0 * ily_stdage1**2
    REAL(8), PARAMETER :: ik_age1 = 0.08563d0
     REAL(8), PARAMETER :: ik_stdage1 = 1.035768d0
    REAL(8), PARAMETER :: ild_age1 = -1.388311d0
    REAL(8), PARAMETER :: ild_stdage1 = 1.0390140
    REAL(8), PARAMETER :: p_adj_0 = .1963799d0

    REAL(8), PARAMETER :: gnodes_sc=1.d0

    REAL(8),PARAMETER :: sigma_cps=0.0224d0
    REAL(8),PARAMETER :: sigma_nipa=0.02116d0

    REAL(8),PARAMETER :: sigma_ma2=0.2460d0
    REAL(8),PARAMETER :: sigma_id2=0.14011d0
    REAL(8),PARAMETER :: sigma_ag2=0.0231565171457912d0
    REAL(8),PARAMETER :: sigma_pve = 0.007679477678818
    REAL(8), PARAMETER ::  corr_pve_v = 0.440066534088353
    REAL(8) :: beta_pve, sigma_pve_res

    REAL(8),PARAMETER :: sigma_sc_ag = 1.6d0
    REAL(8),PARAMETER :: sigma_sc_id = SQRT(1.d0 + 2.d0 * 54.d0/100.d0)
    REAL(8), PARAMETER :: sigma_sc_ma = 1.d0

    REAL(8),PARAMETER :: punc_hh = 0.943d0**4
    REAL(8),PARAMETER :: punc_ll = (1.d0 - 0.026d0)**4

    REAL(8),PARAMETER :: theta=0.814109047065451d0
    REAL(8),PARAMETER :: kappa=1.25896250393192d0
    REAL(8),PARAMETER :: xi =0.718613945237227d0
    REAL(8),PARAMETER :: F=0.148078058319806d0
    REAL(8),PARAMETER :: gamma=0.227491060567940d0
    REAL(8), PARAMETER :: beta=0.944115680568841d0
    REAL(8),PARAMETER :: delta_2=0.155061646214665d0
    REAL(8),PARAMETER :: delta_1=1.45083049253965* delta_2

    REAL(8),PARAMETER :: p_delta_1=1.d0
    REAL(8),PARAMETER :: p_delta_2=0.85d0

! GRIDS
! --------------
    REAL(8), parameter :: amin=0    !minimum asset value
    REAL(8), parameter :: amax=15.d0   !max asset
    REAL(8), parameter :: Dmin=0    !minimum durable choice
    REAL(8), parameter :: Dmax=1.5d0 !maximum durable choice
    REAL(8), PARAMETER :: cover_e = 3.d0
    REAL(8), PARAMETER :: cover_u = 3.d0
    REAL(8), parameter :: cmin = 1.d-7
    REAL(8), parameter :: vmin = -1.d7
    REAL(8) :: emin, emax, umin, umax   ! labour income process parameters
    REAL(8) :: zmin, zmax, xmin, xmax
    INTEGER, PARAMETER :: ng = trest+twork
    integer, parameter :: ne = 9  ! size of idiosyncratic labor shock grid (perm)
    integer, parameter :: nu = 5  ! size of idiosyncratic labor shock grid (transitory)
    integer, parameter :: ndp = 2
    integer, parameter :: ns = 2
    integer, parameter :: na = 200 ! size of asset grid
    integer, parameter :: nD = 150 ! size of durable grid
    integer, parameter :: nz = 250 ! size of resource grid (adjust)
    integer, parameter :: nx = 250 ! size of resource grid (adjust)

    REAL(8), DIMENSION(ne,ns) :: enodes  !Nodes for idiosyncratic productivity (perm)
    REAL(8), DIMENSION(nu,ns) :: unodes  !Nodes for idiosyncratic productivity (transitory)
    REAL(8), DIMENSION(ndp) :: delta
    REAL(8), DIMENSION(ng) :: gnodes
    REAL(8), DIMENSION(ng) :: betanodes, eqvnodes  !Nodes for lifecycle profile
    REAL(8), DIMENSION(na) :: anodes  !Nodes for idiosyncratic assets
    REAL(8), DIMENSION(nD) :: Dnodes  !Nodes for idiosyncratic durables
    INTEGER, DIMENSION(nD) :: Dpnodes  !Nodes for idiosyncratic durable
    REAL(8), DIMENSION(nz) :: znodes
    REAL(8), DIMENSION(nx) :: xnodes
    REAL(8), DIMENSION(ns) :: sigma_id, sigma_ag, sigma_ar, sigma_ma, sigma_ma_lc
    REAL(8), DIMENSION(ns) :: mu_id, mu_ar, mu_ma
    REAL(8), DIMENSION(ne,ne,ns) :: Probe, Probecum !Transition probabilities for idiosyncratic productivity (perm)
    REAL(8), DIMENSION(nu,nu,ns) :: Probu, Probucum !Transition probabilities for idiosyncratic productivity (transitory)
    REAL(8), DIMENSION(ns,ns) :: Probs
    REAL(8), DIMENSION(ndp,ndp) :: Probdp, Probdpcum

! SIMULATION
! --------------
    INTEGER, PARAMETER :: numsim=4000
    INTEGER, PARAMETER :: simlives = numsim / ng + 2
    INTEGER, PARAMETER :: agent_age = 2000
    INTEGER, PARAMETER :: agents= ng*agent_age
    INTEGER, PARAMETER :: burnin=ng+1
    REAL(8), PARAMETER :: p_adj_0_tune = 1.5d0

! SHOCKS
! --------------
    INTEGER, PARAMETER :: rep = 100
    INTEGER, PARAMETER :: rep_out = 1
    INTEGER, PARAMETER :: shck_c = 3
    INTEGER, PARAMETER :: numshock=2*ng
    INTEGER, PARAMETER :: shocklives = numshock / ng + 2
    INTEGER, PARAMETER :: yr1_shock = 1956
    INTEGER, PARAMETER :: yr_end_shock = 2018
    INTEGER, PARAMETER :: shockseries1_n = 89
    REAL(8), DIMENSION(shockseries1_n) :: shockseries1
    INTEGER, PARAMETER :: shockseries1_start = yr_end_shock+1-yr1_shock
    INTEGER, PARAMETER :: shck_c_period = yr_end_shock+1-2007
    INTEGER, PARAMETER :: s_shck_period = yr_end_shock+1-2008

! Cohort shocks
! ---
    INTEGER, PARAMETER :: coh_size = 10
    INTEGER, PARAMETER :: shockseriescoh_n    = 56
    REAL(8), DIMENSION(shockseriescoh_n,twork) :: shockseriescoh, unempseriescoh
    REAL(8), DIMENSION(shockseriescoh_n) :: shockseriescoh_agg, unempseriescoh_agg
    INTEGER, PARAMETER :: coh_fe_n = 56
    REAL(8), DIMENSION(coh_fe_n) :: coh_fe
    INTEGER, PARAMETER :: shockseriesmat_n = yr_end_shock-1980+1

! SHOCKS
! --------------
    INTEGER, PARAMETER :: rep_irf=100
    INTEGER, PARAMETER :: irf_exp_c = 2
    INTEGER, PARAMETER :: irf_v_i = 2
    INTEGER, PARAMETER :: irf_s_i = 3
    INTEGER, PARAMETER :: coh_out = 4
    INTEGER, PARAMETER :: irf_coh_c = coh_out+1
    INTEGER, PARAMETER :: irf_c = irf_exp_c+1
    INTEGER, PARAMETER :: irf_len = 6
    INTEGER, PARAMETER :: numirf=ng+irf_len
    INTEGER, PARAMETER :: irflives = 3
    INTEGER, PARAMETER :: irf_pre_s = ng-irf_len+1

END MODULE share
