SUBROUTINE sub_shocks_c(age_t,init_y_irf, init_x_irf, &
  init_d_irf, init_d_nadj_irf,init_delta_irf, &
	alive_t_irf,n_shck_irf,u_shck_irf,p_t_irf, &
	v_shck_irf,m_shck_irf,s_shck_irf,dp_shck_irf)

  ! Generates sequence of idiosyncratic and aggregate shocks
  ! tfp process is AR(1), ag_shocks is nearest grid point,
  ! id_shocks uses nearest position for employment transition
  ! Input: none
  ! Output: array of shocks

  USE share
  USE OMP_LIB
  USE par_zig_mod

  IMPLICIT NONE

  ! SIMULATION
  ! --------------
    INTEGER, DIMENSION(numsim,agents), INTENT(IN) :: age_t

  ! SHOCKS
  ! -------------
    REAL(8), DIMENSION(irflives,agents,rep_irf), INTENT(OUT) :: &
  	 init_y_irf, init_x_irf, init_d_irf
    INTEGER, DIMENSION(irflives,agents,rep_irf) :: init_d_nadj_irf
    INTEGER, DIMENSION(irflives,agents,rep_irf), INTENT(OUT) :: init_delta_irf
    INTEGER, DIMENSION(numirf,agents,rep_irf), INTENT(OUT) :: alive_t_irf
    REAL(8), DIMENSION(numirf,agents,rep_irf,irf_c), INTENT(OUT) :: n_shck_irf
    REAL(8), DIMENSION(numirf,agents,rep_irf), INTENT(OUT) :: dp_shck_irf
    REAL(8), DIMENSION(numirf,agents,rep_irf,irf_c), INTENT(OUT) :: u_shck_irf
    REAL(8), DIMENSION(numirf,agents,rep_irf,irf_c), INTENT(OUT) :: p_t_irf
    REAL(8), DIMENSION(numirf,twork,rep_irf,irf_c), INTENT(OUT) :: v_shck_irf
    REAL(8), DIMENSION(numirf,twork,rep_irf,irf_c), INTENT(OUT) :: m_shck_irf
    INTEGER, DIMENSION(numirf,twork,rep_irf,irf_c), INTENT(OUT) :: s_shck_irf

    REAL(8), DIMENSION(numirf,twork,rep_irf,irf_c) :: v_shck_prim_irf
    REAL(8), DIMENSION(numirf,twork,rep_irf,irf_c) :: m_shck_prim_irf
    REAL(8) :: rand_shock, init_y_irf_temp
    REAL(8), DIMENSION(agents) :: rand_shock_vec, rand_shock_vec2
    INTEGER :: j, time, i, k, wts_count

    INTEGER, DIMENSION(agents) :: init_loc

    INTEGER  :: reset, npar, numthreads
    INTEGER, DIMENSION(agents)  :: kpar
    INTEGER, DIMENSION(:), ALLOCATABLE :: seed
    INTEGER :: grainsize = 32

    !$OMP PARALLEL
    !$OMP DO
    DO i=1, agents
    init_y_irf(:,i,:) = 0.d0
    init_x_irf(:,i,:) = 0.d0
    init_d_irf(:,i,:) = 0.d0
    init_d_nadj_irf(:,i,:) = 0
    init_delta_irf(:,i,:) = 0
    alive_t_irf(:,i,:) = 0
    n_shck_irf(:,i,:,:) = 0.d0
    u_shck_irf(:,i,:,:) = 0.d0
    p_t_irf(:,i,:,:) = 0.d0
    dp_shck_irf(:,i,:) = 0.d0
    END DO
    !$OMP END DO
    !$OMP END PARALLEL

    v_shck_irf = 0.d0
    m_shck_irf = 0.d0

  !$OMP PARALLEL
  numthreads = OMP_get_num_threads()
  !$OMP END PARALLEL
  npar=numthreads+1

  ALLOCATE( seed(npar) )
  DO i = 1,npar
        seed(i) = 12345678 * i
  END DO
  reset=1
  CALL par_zigset(npar, seed, grainsize,reset)
  reset=0
  CALL par_zigset(npar, seed, grainsize,reset)

  DO time =1,irflives
  !$OMP PARALLEL
  !$OMP DO
       DO i=1, agents
       kpar(i) = omp_get_thread_num()+1
        DO j = 1, rep_irf

	  rand_shock_vec(i)=par_rnor(kpar(i))
	  init_y_irf(time,i,j) = EXP( ily_age1 + ily_stdage1 * rand_shock_vec(i) )
	  rand_shock_vec(i)=par_rnor(kpar(i))
	  init_d_irf(time,i,j) = EXP( ild_age1 + ild_stdage1 * rand_shock_vec(i) )
	  rand_shock_vec(i)=par_uni(kpar(i))
          IF ( rand_shock_vec(i)> p_adj_0 * p_adj_0_tune ) THEN
	             init_d_nadj_irf(time,i,j) = 1
          END IF
          rand_shock_vec(i)=par_rnor(kpar(i))
	         init_x_irf(time,i,j) = MAX( ik_age1 + ik_stdage1 * rand_shock_vec(i), -eta*init_d_irf(time,i,j) )
          IF (init_x_irf(time,i,j) >0.d0) THEN
          init_x_irf(time,i,j) = init_x_irf(time,i,j)*r
          ELSE
          init_x_irf(time,i,j) = init_x_irf(time,i,j)*(r + rk)
          END IF
          rand_shock_vec(i)=par_uni(kpar(i))
          IF (rand_shock_vec(i) <= Probdpcum(1,1) ) THEN
          init_delta_irf(time,i,j) = 1
          ELSE
          init_delta_irf(time,i,j) = 2
          END IF
        END DO
       END DO
  !$OMP END DO
  !$OMP END PARALLEL
  END DO

  !$OMP PARALLEL
  !$OMP DO
  DO i=1,agents
  kpar(i) = omp_get_thread_num()+1
  DO j=1,rep_irf
  rand_shock_vec(i)=par_rnor(kpar(i))
  DO k=1,irf_c
  u_shck_irf(1,i,j,k) = EXP(  mu_ma(2) + sigma_ma(2) * rand_shock_vec(i) )
  p_t_irf(1,i,j,k) = init_y_irf(1,i,j)/u_shck_irf(1,i,j,k)
  END DO
  END DO
  END DO
  !$OMP END DO
  !$OMP END PARALLEL
  alive_t_irf(1,:,:) = 1
  m_shck_irf = 1.d0

  s_shck_irf = snorm
  !$OMP PARALLEL DO
  DO j=1,rep_irf
  kpar(j) = omp_get_thread_num()+1
   DO time =1,numirf
     IF (time.GT.1 .AND. time.LE.irf_pre_s) THEN
     rand_shock_vec(j)=par_uni(kpar(j))
       DO k=1,irf_c
         DO i=1,twork
           IF ( rand_shock_vec(j) <= Probs(s_shck_irf(time-1,i,j,k),1) ) THEN
            s_shck_irf(time,i,j,k)=1
           ELSE
            s_shck_irf(time,i,j,k)=2
           END IF
        END DO
       END DO
      ELSE
        DO k=1,irf_c
          DO i=1,twork
          s_shck_irf(time,i,j,k)=2
          END DO
        END DO
      END IF

    rand_shock_vec(j)=par_rnor(kpar(j))
    rand_shock_vec2(j)=par_rnor(kpar(j))
    DO k=1,irf_c
     DO i=1,twork
     v_shck_prim_irf(time,i,j,k) = rand_shock_vec(j)
     m_shck_prim_irf(time,i,j,k) = rand_shock_vec2(j)
     v_shck_irf(time,i,j,k) = EXP( sigma_ag( s_shck_irf(time,i,j,k) ) * v_shck_prim_irf(time,i,j,k) )
     m_shck_irf(time,i,j,k) = v_shck_irf(time,i,j,k)**(beta_pve) * &
	     EXP( m_shck_prim_irf(time,i,j,k)*sigma_pve_res )
     END DO
    END DO

   END DO
  END DO
  !OMP END PARALLEL DO


  !$OMP PARALLEL DO
  DO j=1,rep_irf
    DO i=1,twork
    v_shck_irf(ng+1,i,j,irf_v_i) = EXP( (-2.5d0)*sigma_ag( s_shck_irf(ng+1,i,j,irf_v_i) )  )
    END DO
  END DO

  !$OMP PARALLEL DO
  DO j=1,rep_irf
    DO time=ng+1,numirf
      DO i=1,twork
            s_shck_irf(time,i,j,irf_s_i) = 1
            v_shck_irf(time,i,j,irf_s_i) = EXP( sigma_ag( s_shck_irf(time,i,j,irf_s_i) ) * v_shck_prim_irf(time,i,j,irf_s_i) )
            m_shck_irf(time,i,j,irf_s_i) = v_shck_irf(time,i,j,irf_s_i)**(beta_pve) * &
              EXP( m_shck_prim_irf(time,i,j,irf_s_i)*sigma_pve_res )
        END DO
      END DO
    END DO
  !$OMP END PARALLEL DO

  ! 4.4 Idiosyncratic shocks
  !------
  DO j=1, rep_irf
    DO time=1,numirf

  !$OMP PARALLEL PRIVATE(init_y_irf_temp)
  !$OMP DO
  DO i=1, agents
  kpar(i) = omp_get_thread_num()+1
	IF (time==1) THEN
        init_loc(i) = 2
  END IF

	rand_shock_vec(i)=par_rnor(kpar(i))
  DO k=1,irf_c
  n_shck_irf(time,i,j,k) = EXP( mu_id(s_shck_irf(time,MIN(age_t(time,i),twork),j,k)) + &
      sigma_id(s_shck_irf(time,MIN(age_t(time,i),twork),j,k)) * rand_shock_vec(i) )
  END DO

	IF (time>1) THEN
	rand_shock_vec(i)=par_rnor(kpar(i))
  IF (age_t(time,i)==1) THEN
     DO k=1,irf_c
	   u_shck_irf(time,i,j,k) = EXP(  mu_ma(2) + sigma_ma(2)*rand_shock_vec(i) )
     END DO
  ELSE
     DO k=1,irf_c
     u_shck_irf(time,i,j,k) = EXP(  mu_ma(s_shck_irf(time,MIN(age_t(time,i),twork),j,k)) + &
           sigma_ma(s_shck_irf(time,MIN(age_t(time,i),twork),j,k)) *rand_shock_vec(i) )
     END DO
  END IF

    IF (age_t(time,i)==1) THEN
  		  DO k=1,irf_c
          init_y_irf_temp = init_y_irf(init_loc(i),i,j)*v_shck_irf(time,age_t(time,i),j,k)
          p_t_irf(time,i,j,k) = init_y_irf_temp/u_shck_irf(time,i,j,k)
        END DO
        init_loc(i) = init_loc(i) + 1
	   ELSE
        DO k=1,irf_c
  		    IF (age_t(time,i)<=twork) THEN
  		    p_t_irf(time,i,j,k) = gnodes(age_t(time,i))*p_t_irf(time-1,i,j,k) &
  				*n_shck_irf(time,i,j,k)*v_shck_irf(time,age_t(time,i),j,k)
          ELSE
     		    p_t_irf(time,i,j,k) = gnodes(age_t(time,i))*p_t_irf(time-1,i,j,k)
  		    END IF
        END DO
	  END IF
	END IF

	IF (time<numirf) THEN
	  IF (age_t(time,i)<ng) THEN
	    IF (alive_t_irf(time,i,j)== 1) THEN
            rand_shock_vec(i)=par_uni(kpar(i))
	    	IF( rand_shock_vec(i)<betanodes(age_t(time,i)) ) THEN
	 	alive_t_irf(time+1,i,j) = 1
		ELSE
		alive_t_irf(time+1,i,j) = 0
		END IF
	    END IF
	  ELSE
	 	alive_t_irf(time+1,i,j) = 1
	  END IF
	END IF
        dp_shck_irf(time,i,j)=par_uni(kpar(i))
  END DO
  !$OMP END DO
  !$OMP END PARALLEL
       END DO
    END DO

  END SUBROUTINE sub_shocks_c
